# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from yoti_python_sdk.doc_scan import constants
from yoti_python_sdk.utils import YotiSerializable, remove_null_values
from .requested_check import RequestedCheck


class WatchlistScreeningCheckConfig(YotiSerializable):
    """
    The configuration applied when creating a Watchlist screening check.
    """

    def __init__(self, manual_check, categories):
        """
        :param manual_check: the watchlist screening check manual_check eg. "NEVER"
        :type type: str
        :param categories: list of categories for watchlist screening check config
        :type max_retries: list
        """
        self.__categories = categories
        self.__manual_check = manual_check

    @property
    def manual_check(self):
        """
        Watchlist screening check manual check value

        :return: str
        """
        return self.__manual_check

    @property
    def categories(self):
        """
        Watchlist screening check categories

        :return: list
        """
        return self.__categories

    def to_json(self):
        return remove_null_values(
            {"manual_check": self.manual_check, "categories": self.__categories}
        )


class WatchlistScreeningCheck(RequestedCheck):
    """
    Requests creation of a Watchlist screening check
    """

    def __init__(self, config):
        """
        :param config: the Watchlist screening check configuration
        :type config: WatchlistScreeningCheckConfig
        """
        self.__config = config

    @property
    def type(self):
        return constants.WATCHLIST_SCREENING_CHECK_TYPE

    @property
    def config(self):
        return self.__config


class WatchlistScreeningCheckBuilder(object):
    """
    Builder to assist creation of :class:`WatchlistScreeningCheck`
    """

    def __init__(self):
        self.__categories = None
        self.__manual_check = None

    def with_categories(self, categories):
        """
        Sets the WatchListScreeningCheck categories

        :return: the builder
        :rtype: WatchlistScreeningCheckBuilder
        """
        self.__categories = categories

        return self

    def with_manual_check(self, manual_check):
        """
        Sets the WatchListScreeningCheck manual_check

        :param liveness_type: the manual_check
        :type liveness_type: str
        :return: the builder
        :rtype: WatchlistScreeningCheckBuilder
        """
        self.__manual_check = manual_check

        return self

    def build(self):
        config = WatchlistScreeningCheckConfig(self.__manual_check, self.__categories or [])
        return WatchlistScreeningCheck(config)



from .text_extraction import RequestedTextExtractionTaskBuilder
from .supplementary_doc_text_extraction import (
    RequestedSupplementaryDocTextExtractionTaskBuilder,
)

__all__ = [
    "RequestedTextExtractionTaskBuilder",
    "RequestedSupplementaryDocTextExtractionTaskBuilder",
]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

import json

import yoti_python_sdk
from yoti_python_sdk.doc_scan.endpoint import Endpoint
from yoti_python_sdk.doc_scan.session.retrieve.create_session_result import (
    CreateSessionResult,
)
from yoti_python_sdk.doc_scan.session.retrieve.get_session_result import (
    GetSessionResult,
)
from yoti_python_sdk.doc_scan.session.retrieve.media_value import MediaValue
from yoti_python_sdk.http import SignedRequest
from yoti_python_sdk.utils import YotiEncoder
from .exception import DocScanException
from .support import SupportedDocumentsResponse


class DocScanClient(object):
    """
    Client used for communication with the Yoti Doc Scan service where any
    signed request is required
    """

    def __init__(self, sdk_id, key, api_url=None):
        self.__sdk_id = sdk_id
        self.__key = key
        if api_url is not None:
            self.__api_url = api_url
        else:
            self.__api_url = yoti_python_sdk.YOTI_DOC_SCAN_API_URL

    def create_session(self, session_spec):
        """
        Creates a Doc Scan session using the supplied session specification

        :param session_spec: the session specification
        :type session_spec: SessionSpec
        :return: the create session result
        :rtype: CreateSessionResult
        :raises DocScanException: if there was an error creating the session
        """
        payload = json.dumps(session_spec, cls=YotiEncoder).encode("utf-8")

        request = (
            SignedRequest.builder()
            .with_post()
            .with_pem_file(self.__key)
            .with_base_url(self.__api_url)
            .with_endpoint(Endpoint.create_docs_session_path())
            .with_param("sdkId", self.__sdk_id)
            .with_payload(payload)
            .with_header("Content-Type", "application/json")
            .build()
        )
        response = request.execute()

        if response.status_code != 201:
            raise DocScanException("Failed to create session", response)

        data = json.loads(response.text)
        return CreateSessionResult(data)

    def get_session(self, session_id):
        """
        Retrieves the state of a previously created Yoti Doc Scan session

        :param session_id: the session ID
        :type session_id: str
        :return: the session state
        :rtype: GetSessionResult
        :raises DocScanException: if there was an error retrieving the session
        """
        request = (
            SignedRequest.builder()
            .with_get()
            .with_pem_file(self.__key)
            .with_base_url(self.__api_url)
            .with_endpoint(Endpoint.retrieve_docs_session_path(session_id))
            .with_param("sdkId", self.__sdk_id)
            .build()
        )
        response = request.execute()

        if response.status_code != 200:
            raise DocScanException("Failed to retrieve session", response)

        data = json.loads(response.text)
        return GetSessionResult(data)

    def delete_session(self, session_id):
        """
        Deletes a previously created Yoti Doc Scan session and
        all of its related resources

        :param session_id: the session id to delete
        :type session_id: str
        :rtype: None
        :raises DocScanException: if there was an error deleting the session
        """
        request = (
            SignedRequest.builder()
            .with_http_method("DELETE")
            .with_pem_file(self.__key)
            .with_base_url(self.__api_url)
            .with_endpoint(Endpoint.delete_docs_session_path(session_id))
            .with_param("sdkId", self.__sdk_id)
            .build()
        )
        response = request.execute()

        if response.status_code < 200 or response.status_code >= 300:
            raise DocScanException("Failed to delete session", response)

    def get_media_content(self, session_id, media_id):
        """
        Retrieves media related to a Yoti Doc Scan session
        based on the supplied media ID

        :param session_id: the session ID
        :type session_id: str
        :param media_id: the media ID
        :type media_id: str
        :return: the media
        :rtype: MediaValue
        :raises DocScanException: if there was an error retrieving the media content
        """
        request = (
            SignedRequest.builder()
            .with_get()
            .with_pem_file(self.__key)
            .with_base_url(self.__api_url)
            .with_endpoint(Endpoint.get_media_content_path(session_id, media_id))
            .with_param("sdkId", self.__sdk_id)
            .build()
        )
        response = request.execute()

        if response.status_code == 204:
            return None

        if response.status_code != 200:
            raise DocScanException("Failed to retrieve media content", response)

        media_mime_type = response.headers["Content-Type"]
        media_content = response.content
        return MediaValue(media_mime_type, media_content)

    def delete_media_content(self, session_id, media_id):
        """
        Deletes media related to a Yoti Doc Scan session
        based on the supplied media ID

        :param session_id: the session ID
        :type session_id: str
        :param media_id: the media ID
        :type media_id: str
        :rtype: None
        :raises DocScanException: if there was an error deleting the media content
        """
        request = (
            SignedRequest.builder()
            .with_http_method("DELETE")
            .with_pem_file(self.__key)
            .with_base_url(self.__api_url)
            .with_endpoint(Endpoint.delete_media_path(session_id, media_id))
            .with_param("sdkId", self.__sdk_id)
            .build()
        )

        response = request.execute()
        if response.status_code < 200 or response.status_code >= 300:
            raise DocScanException("Failed to delete media content", response)

    def get_supported_documents(self):
        """
        Retrieves a list of all of the currently supported documents

        :return: the supported documents response
        :rtype: SupportedDocumentsResponse
        """
        request = (
            SignedRequest.builder()
            .with_http_method("GET")
            .with_pem_file(self.__key)
            .with_base_url(self.__api_url)
            .with_endpoint(Endpoint.get_supported_documents_path())
            .build()
        )

        response = request.execute()
        if response.status_code < 200 or response.status_code >= 300:
            raise DocScanException("Failed to retrieve supported documents", response)

        parsed = json.loads(response.text)
        return SupportedDocumentsResponse(parsed)



from abc import ABCMeta

from yoti_python_sdk.utils import YotiSerializable, remove_null_values


class DocumentFilter(YotiSerializable):
    __metaclass__ = ABCMeta

    def __init__(self, filter_type):
        self.__filter_type = filter_type

    @property
    def type(self):
        return self.__filter_type

    def to_json(self):
        return remove_null_values({"type": self.type})



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sharepubapi_v1/Sharing.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import Policy_pb2 as sharepubapi__v1_dot_Policy__pb2
from . import DataEntry_pb2 as sharepubapi__v1_dot_DataEntry__pb2
from yoti_python_sdk.protobuf.compubapi_v1 import Metadata_pb2 as compubapi__v1_dot_Metadata__pb2
from yoti_python_sdk.protobuf.compubapi_v1 import IdentityProfile_pb2 as compubapi__v1_dot_IdentityProfile__pb2
from devicepubapi_v1 import StaticCredentialAuth_pb2 as devicepubapi__v1_dot_StaticCredentialAuth__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1csharepubapi_v1/Sharing.proto\x12\x18yoti.core.sharepubapi_v1\x1a\x1bsharepubapi_v1/Policy.proto\x1a\x1esharepubapi_v1/DataEntry.proto\x1a\x1b\x63ompubapi_v1/Metadata.proto\x1a\"compubapi_v1/IdentityProfile.proto\x1a*devicepubapi_v1/StaticCredentialAuth.proto\"\xba\x04\n\x13StartSharingRequest\x12\x16\n\x0e\x63orrelation_id\x18\x01 \x01(\t\x12\x30\n\x06policy\x18\x02 \x01(\x0b\x32 .yoti.core.sharepubapi_v1.Policy\x12\x15\n\rattribute_ids\x18\x03 \x03(\x0c\x12\x13\n\x0bwrapped_key\x18\x04 \x01(\x0c\x12\x12\n\ncredential\x18\x05 \x01(\x0c\x12\x11\n\tauth_list\x18\x06 \x01(\x0c\x12\x18\n\x0bttl_seconds\x18\x07 \x01(\x03H\x00\x88\x01\x01\x12\x1a\n\rone_time_only\x18\x08 \x01(\x08H\x01\x88\x01\x01\x12\x37\n\nextra_data\x18\t \x03(\x0b\x32#.yoti.core.sharepubapi_v1.DataEntry\x12\x1a\n\x12\x62illing_account_id\x18\n \x01(\t\x12\x19\n\x11\x62illing_source_id\x18\x0b \x01(\t\x12\x30\n\x07subject\x18\x0c \x01(\x0b\x32\x1f.yoti.core.compubapi_v1.Subject\x12:\n\x0f\x64\x65vice_metadata\x18\xc0\x0c \x01(\x0b\x32 .yoti.core.compubapi_v1.Metadata\x12P\n\x16static_credential_auth\x18\xb8\x17 \x01(\x0b\x32/.yoti.core.devicepubapi_v1.StaticCredentialAuthB\x0e\n\x0c_ttl_secondsB\x10\n\x0e_one_time_only\"\x80\x01\n\x14StartSharingResponse\x12\x15\n\rsharing_token\x18\x01 \x01(\x0c\x12\x30\n\x06policy\x18\x02 \x01(\x0b\x32 .yoti.core.sharepubapi_v1.Policy\x12\x1f\n\x17sharing_token_for_stats\x18\x03 \x01(\t\"\xf1\x03\n\x16\x43ompleteSharingRequest\x12\x15\n\rsharing_token\x18\x01 \x01(\x0c\x12\x16\n\x0e\x63orrelation_id\x18\x02 \x01(\t\x12\x30\n\x06policy\x18\x03 \x01(\x0b\x32 .yoti.core.sharepubapi_v1.Policy\x12\x15\n\rattribute_ids\x18\x04 \x03(\x0c\x12\x13\n\x0bwrapped_key\x18\x05 \x01(\x0c\x12\x12\n\ncredential\x18\x06 \x01(\x0c\x12\x11\n\tauth_list\x18\x07 \x01(\x0c\x12\x14\n\x0csession_data\x18\x08 \x01(\t\x12\x30\n\x06issuer\x18\t \x01(\x0e\x32 .yoti.core.sharepubapi_v1.Issuer\x12\x36\n\ttransport\x18\n \x01(\x0e\x32#.yoti.core.sharepubapi_v1.Transport\x12\x37\n\nextra_data\x18\x0b \x03(\x0b\x32#.yoti.core.sharepubapi_v1.DataEntry\x12\x14\n\x0creference_id\x18\x0c \x01(\t\x12\x18\n\x10mobile_device_id\x18\r \x01(\t\x12:\n\x0f\x64\x65vice_metadata\x18\xc0\x0c \x01(\x0b\x32 .yoti.core.compubapi_v1.Metadata*7\n\x06Issuer\x12\x08\n\x04\x43ORE\x10\x00\x12\x0b\n\x07\x43ONNECT\x10\x01\x12\n\n\x06PORTAL\x10\x02\x12\n\n\x06MOBILE\x10\x03*0\n\tTransport\x12\r\n\tUNDEFINED\x10\x00\x12\x07\n\x03URI\x10\x01\x12\x0b\n\x07QR_CODE\x10\x02\x42h\n\x17\x63om.yoti.sharepubapi_v1B\x0cSharingProtoZ.go.internal.yoti.com/proto/core/sharepubapi_v1\xba\x02\x0eSharepubapiV1_b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'Sharing_pb2.py', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.yoti.sharepubapi_v1B\014SharingProtoZ.go.internal.yoti.com/proto/core/sharepubapi_v1\272\002\016SharepubapiV1_'
  _ISSUER._serialized_start=1432
  _ISSUER._serialized_end=1487
  _TRANSPORT._serialized_start=1489
  _TRANSPORT._serialized_end=1537
  _STARTSHARINGREQUEST._serialized_start=229
  _STARTSHARINGREQUEST._serialized_end=799
  _STARTSHARINGRESPONSE._serialized_start=802
  _STARTSHARINGRESPONSE._serialized_end=930
  _COMPLETESHARINGREQUEST._serialized_start=933
  _COMPLETESHARINGREQUEST._serialized_end=1430
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sharepubapi_v1/DataEntry.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1esharepubapi_v1/DataEntry.proto\x12\x18yoti.core.sharepubapi_v1\"\xe7\x01\n\tDataEntry\x12\x36\n\x04type\x18\x01 \x01(\x0e\x32(.yoti.core.sharepubapi_v1.DataEntry.Type\x12\r\n\x05value\x18\x02 \x01(\x0c\"\x92\x01\n\x04Type\x12\r\n\tUNDEFINED\x10\x00\x12\x0b\n\x07INVOICE\x10\x01\x12\x17\n\x13PAYMENT_TRANSACTION\x10\x02\x12\x0c\n\x08LOCATION\x10\x03\x12\x0f\n\x0bTRANSACTION\x10\x04\x12\x1b\n\x17\x41GE_VERIFICATION_SECRET\x10\x05\x12\x19\n\x15THIRD_PARTY_ATTRIBUTE\x10\x06\x42j\n\x17\x63om.yoti.sharepubapi_v1B\x0e\x44\x61taEntryProtoZ.go.internal.yoti.com/proto/core/sharepubapi_v1\xba\x02\x0eSharepubapiV1_b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'DataEntry_pb2.py', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.yoti.sharepubapi_v1B\016DataEntryProtoZ.go.internal.yoti.com/proto/core/sharepubapi_v1\272\002\016SharepubapiV1_'
  _DATAENTRY._serialized_start=61
  _DATAENTRY._serialized_end=292
  _DATAENTRY_TYPE._serialized_start=146
  _DATAENTRY_TYPE._serialized_end=292
# @@protoc_insertion_point(module_scope)



class Endpoint(object):
    @staticmethod
    def create_docs_session_path():
        return "/sessions"

    @staticmethod
    def retrieve_docs_session_path(session_id):
        return "/sessions/{sessionId}".format(sessionId=session_id)

    @staticmethod
    def delete_docs_session_path(session_id):
        return Endpoint.retrieve_docs_session_path(session_id)

    @staticmethod
    def get_media_content_path(session_id, media_id):
        return "/sessions/{sessionId}/media/{mediaId}/content".format(
            sessionId=session_id, mediaId=media_id
        )

    @staticmethod
    def delete_media_path(session_id, media_id):
        return Endpoint.get_media_content_path(session_id, media_id)

    @staticmethod
    def get_supported_documents_path():
        return "/supported-documents"



# -*- coding: utf-8 -*-
from __future__ import unicode_literals


class WantedAnchorBuilder(object):
    def __init__(self):
        self.__name = ""
        self.__subtype = ""

    def with_value(self, name):
        """
        :param name: The type of anchor as a string
        """
        self.__name = name
        return self

    def with_subtype(self, subtype):
        """
        :param subtype: Subtype information as a string
        """
        self.__subtype = subtype
        return self

    def build(self):
        """
        :returns: A dict containing the anchor specification
        """
        return {"name": self.__name, "sub_type": self.__subtype}



class RecommendationResponse(object):
    """
    Represents the recommendation given for a check
    """

    def __init__(self, data=None):
        """
        :param data: the data to parse
        :type data: dict or None
        """
        if data is None:
            data = dict()

        self.__value = data.get("value", None)
        self.__reason = data.get("reason", None)
        self.__recovery_suggestion = data.get("recovery_suggestion", None)

    @property
    def value(self):
        """
        Returns the value of the recommendation

        :return: the value
        :rtype: str or None
        """
        return self.__value

    @property
    def reason(self):
        """
        Returns the reason of the recommendation

        :return: the reason
        :rtype: str or None
        """
        return self.__reason

    @property
    def recovery_suggestion(self):
        """
        Returns the recovery suggestion of the recommendation

        :return: the recovery suggestion
        :rtype: str or None
        """
        return self.__recovery_suggestion



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sharepubapi_v1/ExtraData.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import DataEntry_pb2 as sharepubapi__v1_dot_DataEntry__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1esharepubapi_v1/ExtraData.proto\x12\x18yoti.core.sharepubapi_v1\x1a\x1esharepubapi_v1/DataEntry.proto\">\n\tExtraData\x12\x31\n\x04list\x18\x01 \x03(\x0b\x32#.yoti.core.sharepubapi_v1.DataEntryBj\n\x17\x63om.yoti.sharepubapi_v1B\x0e\x45xtraDataProtoZ.go.internal.yoti.com/proto/core/sharepubapi_v1\xba\x02\x0eSharepubapiV1_b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ExtraData_pb2.py', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.yoti.sharepubapi_v1B\016ExtraDataProtoZ.go.internal.yoti.com/proto/core/sharepubapi_v1\272\002\016SharepubapiV1_'
  _EXTRADATA._serialized_start=92
  _EXTRADATA._serialized_end=154
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

import iso8601
from iso8601 import ParseError


class MediaResponse(object):
    """
    Represents a media resource
    """

    def __init__(self, data=None):
        """
        :param data: the data to parse
        :type data: dict or None
        """
        if data is None:
            data = dict()

        self.__id = data.get("id", None)
        self.__type = data.get("type", None)
        self.__created = self.__parse_date(data.get("created", None))
        self.__last_updated = self.__parse_date(data.get("last_updated", None))

    @staticmethod
    def __parse_date(date):
        if date is None:
            return date

        try:
            return iso8601.parse_date(date)
        except ParseError:
            return None

    @property
    def id(self):
        """
        The ID of the media resource

        :return: the ID
        :rtype: str or None
        """
        return self.__id

    @property
    def type(self):
        """
        The type of the media resource, e.g. "JSON"

        :return: the type
        :rtype: str or None
        """
        return self.__type

    @property
    def created(self):
        """
        The date the media resource was created

        :return: the created date
        :rtype: datetime.datetime or None
        """
        return self.__created

    @property
    def last_updated(self):
        """
        The date the media resource was last updated

        :return: the last updated date
        :rtype: datetime.datetime or None
        """
        return self.__last_updated



# -*- coding: utf-8 -*-
from __future__ import unicode_literals


class LocationConstraintExtensionBuilder(object):
    LOCATION_CONSTRAINT = "LOCATION_CONSTRAINT"

    def __init__(self):
        self.__extension = {}
        self.__extension["type"] = self.LOCATION_CONSTRAINT
        self.__extension["content"] = {}
        self.__device_location = {
            "latitude": None,
            "longitude": None,
            "radius": None,
            "max_uncertainty_radius": None,
        }
        self.__extension["content"]["expected_device_location"] = self.__device_location

    def with_latitude(self, latitude):
        if not isinstance(latitude, float) and not isinstance(latitude, int):
            raise ValueError("Latitude must be float or int")
        if not -90 <= latitude <= 90:
            raise ValueError("Latitude must be between -90 and 90 degrees")
        self.__device_location["latitude"] = latitude
        return self

    def with_longitude(self, longitude):
        if not isinstance(longitude, float) and not isinstance(longitude, int):
            raise ValueError("Lontitude must be float or int")
        if not -180 <= longitude <= 180:
            raise ValueError("Longitude must be between -180 and 180 degrees")
        self.__device_location["longitude"] = longitude
        return self

    def with_radius(self, radius):
        if not isinstance(radius, float) and not isinstance(radius, int):
            raise ValueError("Radius must be float or int")
        if not 0 <= radius:
            raise ValueError("Radius must be >= 0")
        self.__device_location["radius"] = radius
        return self

    def with_uncertainty(self, uncertainty):
        if not isinstance(uncertainty, float) and not isinstance(uncertainty, int):
            raise ValueError("Uncertainty must be float or int")
        if not 0 <= uncertainty:
            raise ValueError("Uncertainty must be >= 0")
        self.__device_location["max_uncertainty_radius"] = uncertainty
        return self

    def build(self):
        return self.__extension.copy()



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from .resource_response import ResourceResponse
from .face_map_response import FaceMapResponse
from .frame_response import FrameResponse


class LivenessResourceResponse(ResourceResponse):
    """
    Represents a Liveness resource for a given session
    """

    def __init__(self, data=None):
        if data is None:
            data = dict()

        ResourceResponse.__init__(self, data)

        self.__liveness_type = data.get("liveness_type", None)

    @property
    def liveness_type(self):
        return self.__liveness_type


class ZoomLivenessResourceResponse(LivenessResourceResponse):
    """
    Represents a Zoom Liveness resource for a given session
    """

    def __init__(self, data=None):
        """
        :param data: the data to parse
        :type data: dict or None
        """
        if data is None:
            data = dict()

        LivenessResourceResponse.__init__(self, data)

        self.__facemap = (
            FaceMapResponse(data["facemap"]) if "facemap" in data.keys() else None
        )
        self.__frames = [FrameResponse(frame) for frame in data.get("frames", [])]

    @property
    def facemap(self):
        """
        Returns the associated facemap information for
        the zoom liveness resource

        :return: the facemap
        :rtype: FaceMapResponse or None
        """
        return self.__facemap

    @property
    def frames(self):
        """
        Returns the list of associated frames for
        the zoom liveness resource

        :return: the frames
        :rtype: list[FrameResponse]
        """
        return self.__frames



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sharepubapi_v1/ScanYotiCompleteShare.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yoti_python_sdk.protobuf.compubapi_v1 import Metadata_pb2 as compubapi__v1_dot_Metadata__pb2
from . import Sharing_pb2 as sharepubapi__v1_dot_Sharing__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*sharepubapi_v1/ScanYotiCompleteShare.proto\x12\x18yoti.core.sharepubapi_v1\x1a\x1b\x63ompubapi_v1/Metadata.proto\x1a\x1csharepubapi_v1/Sharing.proto\"\xed\x01\n\x15ScanYotiCompleteShare\x12\x15\n\rsharing_token\x18\x01 \x01(\x0c\x12\x30\n\x06issuer\x18\x02 \x01(\x0e\x32 .yoti.core.sharepubapi_v1.Issuer\x12\x36\n\ttransport\x18\x03 \x01(\x0e\x32#.yoti.core.sharepubapi_v1.Transport\x12:\n\x0f\x64\x65vice_metadata\x18\xc0\x0c \x01(\x0b\x32 .yoti.core.compubapi_v1.Metadata\x12\x17\n\x0e\x63orrelation_id\x18\xc2\x0c \x01(\tBAZ.go.internal.yoti.com/proto/core/sharepubapi_v1\xba\x02\x0eSharepubapiV1_b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ScanYotiCompleteShare_pb2.py', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z.go.internal.yoti.com/proto/core/sharepubapi_v1\272\002\016SharepubapiV1_'
  _SCANYOTICOMPLETESHARE._serialized_start=132
  _SCANYOTICOMPLETESHARE._serialized_end=369
# @@protoc_insertion_point(module_scope)



from yoti_python_sdk import config


class Attribute:
    def __init__(self, name=None, value=None, anchors=None):
        if name is None:
            name = ""
        if value is None:
            value = ""
        if anchors is None:
            anchors = {}
        self.__name = name
        self.__value = value
        self.__anchors = anchors

    @property
    def name(self):
        return self.__name

    @property
    def value(self):
        return self.__value

    @property
    def anchors(self):
        return self.__anchors

    @property
    def sources(self):
        return list(
            filter(lambda a: a.anchor_type == config.ANCHOR_SOURCE, self.__anchors)
        )

    @property
    def verifiers(self):
        return list(
            filter(lambda a: a.anchor_type == config.ANCHOR_VERIFIER, self.__anchors)
        )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: compubapi_v1/DocumentFields.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import Address_pb2 as compubapi__v1_dot_Address__pb2
from . import MRZ_pb2 as compubapi__v1_dot_MRZ__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!compubapi_v1/DocumentFields.proto\x12\x16yoti.core.compubapi_v1\x1a\x1a\x63ompubapi_v1/Address.proto\x1a\x16\x63ompubapi_v1/MRZ.proto\"\xe4\x07\n\x0e\x44ocumentFields\x12\x11\n\tfull_name\x18\x01 \x01(\t\x12\x15\n\rdate_of_birth\x18\x02 \x01(\t\x12\x13\n\x0bnationality\x18\x03 \x01(\t\x12\x13\n\x0bgiven_names\x18\x04 \x01(\t\x12\x12\n\nfirst_name\x18\x05 \x01(\t\x12\x13\n\x0bmiddle_name\x18\x06 \x01(\t\x12\x13\n\x0b\x66\x61mily_name\x18\x07 \x01(\t\x12\x16\n\x0eplace_of_birth\x18\x08 \x01(\t\x12\x18\n\x10\x63ountry_of_birth\x18\t \x01(\t\x12\x0e\n\x06gender\x18\n \x01(\t\x12\x13\n\x0bname_prefix\x18\x0b \x01(\t\x12\x13\n\x0bname_suffix\x18\x0c \x01(\t\x12\x18\n\x10\x66irst_name_alias\x18\r \x01(\t\x12\x19\n\x11middle_name_alias\x18\x0e \x01(\t\x12\x19\n\x11\x66\x61mily_name_alias\x18\x0f \x01(\t\x12\x0e\n\x06weight\x18\x10 \x01(\t\x12\x0e\n\x06height\x18\x11 \x01(\t\x12\x11\n\teye_color\x18\x12 \x01(\t\x12\x42\n\x19structured_postal_address\x18\x13 \x01(\x0b\x32\x1f.yoti.core.compubapi_v1.Address\x12\x15\n\rdocument_type\x18\x14 \x01(\t\x12\x17\n\x0fissuing_country\x18\x15 \x01(\t\x12\x17\n\x0f\x64ocument_number\x18\x16 \x01(\t\x12\x17\n\x0f\x65xpiration_date\x18\x17 \x01(\t\x12\x15\n\rdate_of_issue\x18\x18 \x01(\t\x12\x19\n\x11issuing_authority\x18\x19 \x01(\t\x12(\n\x03mrz\x18\x1a \x01(\x0b\x32\x1b.yoti.core.compubapi_v1.MRZ\x12\x14\n\x0corganisation\x18\x1b \x01(\t\x12&\n\x1epersonal_identification_number\x18\x1c \x01(\t\x12\x13\n\x0bparent_name\x18\x1e \x01(\t\x12\x1d\n\x15\x64riving_licence_class\x18\x1f \x01(\t\x12(\n driving_licence_restriction_code\x18  \x01(\t\x12\x13\n\x0bprovisional\x18\" \x01(\x08\x12\x16\n\x0eplace_of_issue\x18# \x01(\t\x12 \n\x18\x64riving_licence_endorsed\x18$ \x01(\t\x12\x13\n\x0b\x63\x61rd_number\x18% \x01(\t\x12\x43\n\x11\x64ocument_template\x18& \x01(\x0b\x32(.yoti.core.compubapi_v1.DocumentTemplateJ\x04\x08\x1d\x10\x1eJ\x04\x08!\x10\"\"C\n\x10\x44ocumentTemplate\x12\x17\n\x0f\x66ront_page_name\x18\x01 \x01(\t\x12\x16\n\x0e\x62\x61\x63k_page_name\x18\x02 \x01(\t\"W\n\x16\x45xpandedDocumentFields\x12=\n\x06\x66ields\x18\x01 \x03(\x0b\x32-.yoti.core.compubapi_v1.ExpandedDocumentField\"\x86\x01\n\x15\x45xpandedDocumentField\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x12\x0e\n\x06locale\x18\x03 \x01(\t\x12\x0e\n\x06source\x18\x04 \x01(\t\x12\x14\n\x0cis_non_latin\x18\x05 \x01(\x08\x12\x1a\n\x12is_transliteration\x18\x06 \x01(\x08\x42i\n\x15\x63om.yoti.compubapi_v1B\x13\x44ocumentFieldsProtoZ,go.internal.yoti.com/proto/core/compubapi_v1\xba\x02\x0c\x43ompubapiV1_b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'DocumentFields_pb2.py', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\025com.yoti.compubapi_v1B\023DocumentFieldsProtoZ,go.internal.yoti.com/proto/core/compubapi_v1\272\002\014CompubapiV1_'
  _DOCUMENTFIELDS._serialized_start=114
  _DOCUMENTFIELDS._serialized_end=1110
  _DOCUMENTTEMPLATE._serialized_start=1112
  _DOCUMENTTEMPLATE._serialized_end=1179
  _EXPANDEDDOCUMENTFIELDS._serialized_start=1181
  _EXPANDEDDOCUMENTFIELDS._serialized_end=1268
  _EXPANDEDDOCUMENTFIELD._serialized_start=1271
  _EXPANDEDDOCUMENTFIELD._serialized_end=1405
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from yoti_python_sdk.doc_scan import constants
from yoti_python_sdk.utils import YotiSerializable, remove_null_values
from .requested_check import RequestedCheck


class RequestedFaceMatchCheckConfig(YotiSerializable):
    """
    The configuration applied when creating a FaceMatch Check
    """

    def __init__(self, manual_check):
        """
        :param manual_check: the manual check value
        :type manual_check: str
        """
        self.__manual_check = manual_check

    @property
    def manual_check(self):
        """
        Returns a value for a manual check for a given
        FaceMatch Check

        :return: the manual check value
        :rtype: str
        """
        return self.__manual_check

    def to_json(self):
        return remove_null_values({"manual_check": self.manual_check})


class RequestedFaceMatchCheck(RequestedCheck):
    """
    Requests creation of a FaceMatch Check
    """

    def __init__(self, config):
        """
        :param config: the requested FaceMatch check configuration
        :type config: RequestedFaceMatchCheckConfig
        """
        self.__config = config

    @property
    def type(self):
        return constants.ID_DOCUMENT_FACE_MATCH

    @property
    def config(self):
        return self.__config


class RequestedFaceMatchCheckBuilder(object):
    """
    Builder to assist with creation of :class:`RequestedFaceMatchCheck`
    """

    def __init__(self):
        self.__manual_check = None

    def with_manual_check_always(self):
        """
        Sets the value of manual check to "ALWAYS"

        :return: the builder
        :rtype: RequestedFaceMatchCheckBuilder
        """
        self.__manual_check = constants.ALWAYS
        return self

    def with_manual_check_fallback(self):
        """
        Sets the value of manual check to "FALLBACK"

        :return: the builder
        :rtype: RequestedFaceMatchCheckBuilder
        """
        self.__manual_check = constants.FALLBACK
        return self

    def with_manual_check_never(self):
        """
        Sets the value of manual check to "NEVER"

        :return: the builder
        :rtype: RequestedFaceMatchCheckBuilder
        """
        self.__manual_check = constants.NEVER
        return self

    def build(self):
        config = RequestedFaceMatchCheckConfig(self.__manual_check)
        return RequestedFaceMatchCheck(config)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sharepubapi_v1/CancelSharing.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yoti_python_sdk.protobuf.compubapi_v1 import Metadata_pb2 as compubapi__v1_dot_Metadata__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"sharepubapi_v1/CancelSharing.proto\x12\x18yoti.core.sharepubapi_v1\x1a\x1b\x63ompubapi_v1/Metadata.proto\"\xaa\x01\n\x14\x43\x61ncelSharingRequest\x12\x15\n\rsharing_token\x18\x01 \x01(\x0c\x12\x16\n\x0e\x63orrelation_id\x18\x02 \x01(\t\x12\x13\n\x0bwrapped_key\x18\x03 \x01(\x0c\x12\x12\n\ncredential\x18\x04 \x01(\x0c\x12:\n\x0f\x64\x65vice_metadata\x18\xc0\x0c \x01(\x0b\x32 .yoti.core.compubapi_v1.Metadata\"@\n\x19\x43\x61ncelSharingNotification\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x12\n\nerror_code\x18\x02 \x01(\tBn\n\x17\x63om.yoti.sharepubapi_v1B\x12\x43\x61ncelSharingProtoZ.go.internal.yoti.com/proto/core/sharepubapi_v1\xba\x02\x0eSharepubapiV1_b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'CancelSharing_pb2.py', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.yoti.sharepubapi_v1B\022CancelSharingProtoZ.go.internal.yoti.com/proto/core/sharepubapi_v1\272\002\016SharepubapiV1_'
  _CANCELSHARINGREQUEST._serialized_start=94
  _CANCELSHARINGREQUEST._serialized_end=264
  _CANCELSHARINGNOTIFICATION._serialized_start=266
  _CANCELSHARINGNOTIFICATION._serialized_end=330
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

import iso8601
from iso8601 import ParseError

from yoti_python_sdk.doc_scan import constants
from yoti_python_sdk.doc_scan.session.retrieve.generated_check_response import (
    GeneratedCheckResponse,
    GeneratedTextDataCheckResponse,
    GeneratedSupplementaryDocumentTextDataCheckResponse,
)
from yoti_python_sdk.doc_scan.session.retrieve.generated_media import GeneratedMedia


class TaskResponse(object):
    """
    Represents a task
    """

    def __init__(self, data=None):
        """
        :param data: the data to parse
        :type data: dict or None
        """
        if data is None:
            data = dict()

        self.__id = data.get("id", None)
        self.__type = data.get("type", None)
        self.__state = data.get("state", None)

        self.__created = self.__parse_date(data.get("created", None))
        self.__last_updated = self.__parse_date(data.get("last_updated", None))

        self.__generated_checks = [
            self.__parse_generated_check(check)
            for check in data.get("generated_checks", [])
        ]
        self.__generated_media = [
            GeneratedMedia(media) for media in data.get("generated_media", [])
        ]

    @staticmethod
    def __parse_generated_check(generated_check):
        """
        Parse a generated check into an object from a dict
        :param generated_check: the raw generated check
        :type generated_check: dict
        :return: the parse generated check
        :rtype: GeneratedCheckResponse
        """
        types = {
            constants.ID_DOCUMENT_TEXT_DATA_CHECK: GeneratedTextDataCheckResponse,
            constants.SUPPLEMENTARY_DOCUMENT_TEXT_DATA_CHECK: GeneratedSupplementaryDocumentTextDataCheckResponse,
        }

        clazz = types.get(
            generated_check.get("type", None),
            GeneratedCheckResponse,  # Default fallback for type
        )
        return clazz(generated_check)

    @staticmethod
    def __parse_date(date):
        """
        Parse a date using the iso8601 library,
        returning None if there was an error

        :param date: the date string to parse
        :type date: str
        :return: the parse date
        :rtype: datetime.datetime or None
        """
        if date is None:
            return None

        try:
            return iso8601.parse_date(date)
        except ParseError:
            return None

    @property
    def type(self):
        """
        Return the type of the task

        :return: the type
        :rtype: str or None
        """
        return self.__type

    @property
    def id(self):
        """
        Return the ID of the task

        :return: the ID
        :rtype: str or None
        """
        return self.__id

    @property
    def state(self):
        """
        Return the state of the task

        :return: the state
        :rtype: str or None
        """
        return self.__state

    @property
    def created(self):
        """
        Return the date the task was created

        :return: the created date
        :rtype: datetime.datetime or None
        """
        return self.__created

    @property
    def last_updated(self):
        """
        Return the date the task was last updated

        :return: the last updated date
        :rtype: datetime.datetime or None
        """
        return self.__last_updated

    @property
    def generated_checks(self):
        """
        Return the list of checks that were generated
        by the task

        :return: the generated checks
        :rtype: list[GeneratedCheckResponse]
        """
        return self.__generated_checks

    @property
    def generated_media(self):
        """
        Return the list of media that has been generated
        by the task

        :return: the list of generated media
        :rtype: list[GeneratedMedia]
        """
        return self.__generated_media


class TextExtractionTaskResponse(TaskResponse):
    """
    Represents an ID Document Text Extraction task response
    """

    @property
    def generated_text_data_checks(self):
        return [
            check
            for check in self.generated_checks
            if isinstance(check, GeneratedTextDataCheckResponse)
        ]


class SupplementaryDocumentTextExtractionTaskResponse(TaskResponse):
    """
    Represents a Supplementary Document Text Extraction task response
    """

    @property
    def generated_text_data_checks(self):
        return [
            check
            for check in self.generated_checks
            if isinstance(check, GeneratedSupplementaryDocumentTextDataCheckResponse)
        ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals
from deprecated import deprecated

from iso8601 import (
    ParseError,
    iso8601,
)

from yoti_python_sdk.doc_scan import constants
from .check_response import (
    AuthenticityCheckResponse,
    CheckResponse,
    FaceMatchCheckResponse,
    IDDocumentComparisonCheckResponse,
    LivenessCheckResponse,
    TextDataCheckResponse,
    SupplementaryDocumentTextDataCheckResponse,
    WatchlistScreeningCheckResponse,
)
from .resource_container import ResourceContainer


class GetSessionResult(object):
    """
    Represents all information about the state of a session
    at the time of the call, including check information,
    resources etc.
    """

    def __init__(self, data):
        """
        :param data: the data to parse
        :type data: dict
        """
        self.__client_session_token_ttl = data.get("client_session_token_ttl", None)
        self.__session_id = data.get("session_id", None)
        self.__user_tracking_id = data.get("user_tracking_id", None)
        self.__state = data.get("state", None)
        self.__client_session_token = data.get("client_session_token", None)
        self.__checks = [self.__parse_check(check) for check in data.get("checks", [])]
        self.__biometric_consent_timestamp = self.__parse_date(
            data.get("biometric_consent", None)
        )

        resources = data.get("resources", None)
        self.__resources = ResourceContainer(resources) or None

    @staticmethod
    def __parse_date(date):
        """
        Attempts to parse a date from string using the
        iso8601 library.  Returns None if there was an error

        :param date: the datestring to parse
        :type date: str
        :return: the parsed date
        :rtype: datetime.datetime or None
        """
        if date is None:
            return date

        try:
            return iso8601.parse_date(date)
        except ParseError:
            return None

    @staticmethod
    def __parse_check(check):
        """
        Parses a check into a sub-type of :class:`CheckResponse`,
        or falls back to CheckResponse if an unknown type

        :param check: the check object
        :type check: dict
        :return: the parsed check
        :rtype: CheckResponse
        """
        types = {
            constants.ID_DOCUMENT_AUTHENTICITY: AuthenticityCheckResponse,
            constants.ID_DOCUMENT_FACE_MATCH: FaceMatchCheckResponse,
            constants.ID_DOCUMENT_TEXT_DATA_CHECK: TextDataCheckResponse,
            constants.LIVENESS: LivenessCheckResponse,
            constants.WATCHLIST_SCREENING_CHECK_TYPE:  WatchlistScreeningCheckResponse,
            constants.ID_DOCUMENT_COMPARISON: IDDocumentComparisonCheckResponse,
            constants.SUPPLEMENTARY_DOCUMENT_TEXT_DATA_CHECK: SupplementaryDocumentTextDataCheckResponse,
        }
        clazz = types.get(check.get("type", None), CheckResponse)
        return clazz(check)

    @property
    def client_session_token_ttl(self):
        """
        The client session token time-to-live (TTL)

        :return: the client session token ttl
        :rtype: int or None
        """
        return self.__client_session_token_ttl

    @property
    def session_id(self):
        """
        The session ID

        :return: the session id
        :rtype: str or None
        """
        return self.__session_id

    @property
    def user_tracking_id(self):
        """
        The user tracking ID for the session

        :return: the user tracking id
        :rtype: str or None
        """
        return self.__user_tracking_id

    @property
    def state(self):
        """
        The state of the session, represented as a string e.g. "COMPLETED"

        :return: the state
        :rtype: str or None
        """
        return self.__state

    @property
    def client_session_token(self):
        """
        The client session token

        :return: the client session token
        :rtype: str or None
        """
        return self.__client_session_token

    @property
    def checks(self):
        """
        The list of Checks associated with the session

        :return: the list of Checks
        :rtype: list[CheckResponse]
        """
        return self.__checks

    def __checks_of_type(self, clazz):
        """
        Filter the list of checks by the class type

        :param clazz: the class
        :type clazz: tuple[type]
        :return:
        :rtype:
        """
        return [check for check in self.checks if isinstance(check, clazz)]

    @property
    def authenticity_checks(self):
        """
        A filtered list of checks, returning only document authenticity checks

        :return: the document authenticity checks
        :rtype: list[AuthenticityCheckResponse]
        """
        return self.__checks_of_type((AuthenticityCheckResponse,))

    @property
    def face_match_checks(self):
        """
        A filtered list of checks, returning only FaceMatch checks

        :return: the FaceMatch checks
        :rtype: list[FaceMatchCheckResponse]
        """
        return self.__checks_of_type((FaceMatchCheckResponse,))

    @property
    @deprecated("replaced by id_document_text_data_checks")
    def text_data_checks(self):
        """
        A filtered list of checks, returning only Text Data checks

        :return: the Text Data checks
        :rtype: list[TextDataCheckResponse]
        """
        return self.id_document_text_data_checks

    @property
    def id_document_text_data_checks(self):
        """
        A filtered list of checks, returning only ID Document Text Data checks

        :return: the Text Data checks
        :rtype: list[TextDataCheckResponse]
        """
        return self.__checks_of_type((TextDataCheckResponse,))

    @property
    def supplementary_document_text_data_checks(self):
        """
        A filtered list of checks, returning only Supplementary Document Text Data checks

        :return: the Text Data checks
        :rtype: list[SupplementaryDocumentTextDataCheckResponse]
        """
        return self.__checks_of_type((SupplementaryDocumentTextDataCheckResponse,))

    @property
    def liveness_checks(self):
        """
        A filtered list of checks, returning only Liveness checks

        :return: the Liveness checks
        :rtype: list[LivenessCheckResponse]
        """
        return self.__checks_of_type((LivenessCheckResponse,))

    @property
    def id_document_comparison_checks(self):
        """
        A filtered list of checks, returning only Identity Document Comparison checks

        :return: the Identity Document Comparison checks
        :rtype: list[IDDocumentComparisonCheckResponse]
        """
        return self.__checks_of_type((IDDocumentComparisonCheckResponse,))

    @property
    def resources(self):
        """
        The resources associated with the session

        :return: the resources
        :rtype: ResourceContainer or None
        """
        return self.__resources

    @property
    def biometric_consent_timestamp(self):
        """
        The biometric constent timestamp

        :return: the biometric constent timestamp
        :rtype: datetime.datetime or None
        """
        return self.__biometric_consent_timestamp



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from .policy.dynamic_policy_builder import DynamicPolicyBuilder


class DynamicScenarioBuilder(object):
    def __init__(self):
        self.__scenario = {
            "policy": DynamicPolicyBuilder().build(),
            "extensions": [],
            "callback_endpoint": "",
        }

    def with_policy(self, policy):
        """
        :param policy: A DynamicPolicy defining the attributes to be requested
        """
        self.__scenario["policy"] = policy
        return self

    def with_extension(self, extension):
        """
        :param extension: An extension to be activated for the scenario
        """
        self.__scenario["extensions"].append(extension)
        return self

    def with_callback_endpoint(self, callback_endpoint):
        """
        :param callback_endpoint: A string with the callback endpoint
        """
        self.__scenario["callback_endpoint"] = callback_endpoint
        return self

    def build(self):
        """
        :returns: Dictionary representation of dynamic scenario
        """
        scenario = self.__scenario.copy()
        scenario["extensions"] = scenario["extensions"][:]
        return scenario



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from iso8601 import ParseError
from iso8601 import iso8601

from .generated_media import GeneratedMedia
from .report_response import ReportResponse


class CheckResponse(object):
    """
    Represents the base attributes for a check for any given session
    """

    def __init__(self, data=None):
        """
        :param data: the data to parse
        :type data: dict or None
        """
        if data is None:
            data = dict()

        self.__id = data.get("id", None)
        self.__state = data.get("state", None)
        self.__type = data.get("type", None)
        self.__resources_used = data.get("resources_used", [])

        self.__report = (
            ReportResponse(data["report"])
            if data.get("report", None) is not None
            else None
        )
        self.__generated_media = [
            GeneratedMedia(media) for media in data.get("generated_media", [])
        ]

        self.__created = self.__parse_date(data.get("created", None))
        self.__last_updated = self.__parse_date(data.get("last_updated", None))

    @staticmethod
    def __parse_date(date):
        """
        Attempts to parse a date from string using the
        iso8601 library.  Returns None if there was an error

        :param date: the datestring to parse
        :type date: str
        :return: the parsed date
        :rtype: datetime.datetime or None
        """
        if date is None:
            return date

        try:
            return iso8601.parse_date(date)
        except ParseError:
            return None

    @property
    def id(self):
        """
        The ID of the check

        :return: the ID
        :rtype: str or None
        """
        return self.__id

    @property
    def type(self):
        """
        The type of the check

        :return: the type
        :rtype: str or None
        """
        return self.__type

    @property
    def state(self):
        """
        The state of the check, e.g. "COMPLETED"

        :return: the state
        :rtype: str or None
        """
        return self.__state

    @property
    def resources_used(self):
        """
        The resources used by the check

        :return: the list of resources used
        :rtype: list[str]
        """
        return self.__resources_used

    @property
    def created(self):
        """
        The date the check was created

        :return: the created date
        :rtype: datetime.datetime or None
        """
        return self.__created

    @property
    def last_updated(self):
        """
        The date the check was last updated

        :return: the last updated date
        :rtype: datetime.datetime or None
        """
        return self.__last_updated

    @property
    def generated_media(self):
        """
        The list of media generated by the check

        :return: the list of generated media
        :rtype: list[GeneratedMedia]
        """
        return self.__generated_media

    @property
    def report(self):
        """
        Report for the check

        :return: the report
        :rtype: ReportResponse or None
        """
        return self.__report


class AuthenticityCheckResponse(CheckResponse):
    """
    Represents a Document Authenticity check for a given session
    """

    pass


class FaceMatchCheckResponse(CheckResponse):
    """
    Represents a FaceMatch check for a given session
    """

    pass


class LivenessCheckResponse(CheckResponse):
    """
    Represents a Liveness check for a given session
    """

    pass


class TextDataCheckResponse(CheckResponse):
    """
    Represents a Text Data check for a given session
    """

    pass


class IDDocumentComparisonCheckResponse(CheckResponse):
    """
    Represents an Identity Document Comparison check for a given session
    """

    pass


class SupplementaryDocumentTextDataCheckResponse(CheckResponse):
    """
    Represents a Supplementary Document Text Data check for a given session
    """

    pass


class WatchlistScreeningCheckResponse(CheckResponse):
    """
    Represents a watchlist screening check for a given session
    """

    pass



# -*- coding: utf-8 -*-
from __future__ import unicode_literals


class CreateSessionResult(object):
    """
    The response to a successful CreateSession call
    """

    def __init__(self, data=None):
        """
        :param data: the data
        :type data: dict or None
        """
        if data is None:
            data = dict()

        self.__client_session_token_ttl = data.get("client_session_token_ttl", None)
        self.__session_deadline = data.get("session_deadline", None)
        self.__session_id = data.get("session_id", None)
        self.__client_session_token = data.get("client_session_token", None)

    @property
    def client_session_token_ttl(self):
        """
        Returns the time-to-live (TTL) for the client session
        token for the created session

        :return: the client session token TTL
        :rtype: int or None
        """
        return self.__client_session_token_ttl

    @property
    def client_session_token(self):
        """
        Returns the client session token for the created session

        :return: the client session token
        :rtype: str or None
        """
        return self.__client_session_token

    @property
    def session_id(self):
        """
        Session ID of the created session

        :return: the session ID
        :rtype: str or None
        """
        return self.__session_id

    @property
    def session_deadline(self):
        """
        The deadline that the session needs to be completed by.

        :return: the session deadline
        :rtype: str or None
        """
        return self.__session_deadline



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: attrpubapi_v1/Signing.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import Attribute_pb2 as attrpubapi__v1_dot_Attribute__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x61ttrpubapi_v1/Signing.proto\x12\x17yoti.core.attrpubapi_v1\x1a\x1d\x61ttrpubapi_v1/Attribute.proto\"\xb4\x01\n\x10\x41ttributeSigning\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c\x12:\n\x0c\x63ontent_type\x18\x03 \x01(\x0e\x32$.yoti.core.attrpubapi_v1.ContentType\x12\x1a\n\x12\x61rtifact_signature\x18\x04 \x01(\x0c\x12\x10\n\x08sub_type\x18\x05 \x01(\t\x12\x19\n\x11\x61ssociated_source\x18\x07 \x01(\tBn\n\x16\x63om.yoti.attrpubapi_v1B\x15\x41ttributeSigningProtoZ-go.internal.yoti.com/proto/core/attrpubapi_v1\xba\x02\rAttrpubapiV1_b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'Signing_pb2.py', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026com.yoti.attrpubapi_v1B\025AttributeSigningProtoZ-go.internal.yoti.com/proto/core/attrpubapi_v1\272\002\rAttrpubapiV1_'
  _ATTRIBUTESIGNING._serialized_start=88
  _ATTRIBUTESIGNING._serialized_end=268
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: compubapi_v1/Metadata.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x63ompubapi_v1/Metadata.proto\x12\x16yoti.core.compubapi_v1\"\xfb\x04\n\x08Metadata\x12\x18\n\x10manufacture_name\x18\x01 \x01(\t\x12\x12\n\nmodel_name\x18\x02 \x01(\t\x12\x0f\n\x07os_name\x18\x03 \x01(\t\x12\x12\n\nos_version\x18\x04 \x01(\t\x12\x17\n\x0fos_vendor_layer\x18\x05 \x01(\t\x12\x16\n\x0e\x63lient_version\x18\x06 \x01(\t\x12\x12\n\nstart_time\x18\x07 \x01(\t\x12\x19\n\x11\x61vailable_sensors\x18\x08 \x03(\t\x12\x14\n\x0c\x64\x65mog_gender\x18\t \x01(\t\x12\x11\n\tdemog_age\x18\n \x01(\t\x12\x15\n\rdemog_country\x18\x0b \x01(\t\x12\x39\n\x07product\x18\x0c \x01(\x0e\x32(.yoti.core.compubapi_v1.Metadata.Product\x12\x14\n\x0c\x62rowser_name\x18\r \x01(\t\x12\x17\n\x0f\x62rowser_version\x18\x0e \x01(\t\x12\x0e\n\x06locale\x18\x0f \x01(\t\x12\x11\n\tstat_uuid\x18\x10 \x01(\t\x12\r\n\x05\x64\x65\x62ug\x18\x11 \x01(\t\x12\x19\n\x11\x64\x65vice_identifier\x18\x12 \x01(\t\"\xc4\x01\n\x07Product\x12\r\n\tUNDEFINED\x10\x00\x12\x0c\n\x08YOTI_APP\x10\x01\x12\x13\n\x0fYPM_BROWSER_EXT\x10\x02\x12\r\n\tYOTI_DOCS\x10\x03\x12\x14\n\x10POSTOFFICEID_APP\x10\x04\x12\x0b\n\x07\x43ONNECT\x10\x05\x12\r\n\tYOTI_SIGN\x10\x06\x12\x07\n\x03\x41VS\x10\x07\x12\r\n\tSCAN_YOTI\x10\x08\x12\r\n\tLBGID_APP\x10\t\x12\x07\n\x03KYC\x10\n\x12\x16\n\x12\x43ONTENT_MODERATION\x10\x0b\x42T\n\x15\x63om.yoti.compubapi_v1Z,go.internal.yoti.com/proto/core/compubapi_v1\xba\x02\x0c\x43ompubapiV1_b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'Metadata_pb2.py', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\025com.yoti.compubapi_v1Z,go.internal.yoti.com/proto/core/compubapi_v1\272\002\014CompubapiV1_'
  _METADATA._serialized_start=56
  _METADATA._serialized_end=691
  _METADATA_PRODUCT._serialized_start=495
  _METADATA_PRODUCT._serialized_end=691
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: compubapi_v1/IdentityProfilePreview.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import IdentityProfileReport_pb2 as compubapi__v1_dot_IdentityProfileReport__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)compubapi_v1/IdentityProfilePreview.proto\x12\x16yoti.core.compubapi_v1\x1a(compubapi_v1/IdentityProfileReport.proto\"\xf4\x01\n\x16IdentityProfilePreview\x12J\n\x12schemes_compliance\x18\x01 \x03(\x0b\x32..yoti.core.compubapi_v1.SchemeComplianceReport\x12H\n\x12identity_assertion\x18\x02 \x01(\x0b\x32,.yoti.core.compubapi_v1.IdentityAssertionExt\x12\x44\n\x12\x63ompliance_reports\x18\x03 \x03(\x0b\x32(.yoti.core.compubapi_v1.ComplianceReportB=Z,go.internal.yoti.com/proto/core/compubapi_v1\xba\x02\x0c\x43ompubapiV1_b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'IdentityProfilePreview_pb2.py', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z,go.internal.yoti.com/proto/core/compubapi_v1\272\002\014CompubapiV1_'
  _IDENTITYPROFILEPREVIEW._serialized_start=112
  _IDENTITYPROFILEPREVIEW._serialized_end=356
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: compubapi_v1/SignedTimestamp.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"compubapi_v1/SignedTimestamp.proto\x12\x16yoti.core.compubapi_v1\"\xbc\x01\n\x0fSignedTimestamp\x12\x0f\n\x07version\x18\x01 \x01(\x05\x12\x11\n\ttimestamp\x18\x02 \x01(\x04\x12\x16\n\x0emessage_digest\x18\x03 \x01(\x0c\x12\x18\n\x10signed_timestamp\x18\x04 \x01(\x0c\x12\x1a\n\x12\x63hain_digest_skip1\x18\x05 \x01(\x0c\x12\x1a\n\x12\x63hain_digest_skip2\x18\x06 \x01(\x0c\x12\x1b\n\x13hmac_key_identifier\x18\x07 \x01(\x05\x42j\n\x15\x63om.yoti.compubapi_v1B\x14SignedTimestampProtoZ,go.internal.yoti.com/proto/core/compubapi_v1\xba\x02\x0c\x43ompubapiV1_b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'SignedTimestamp_pb2.py', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\025com.yoti.compubapi_v1B\024SignedTimestampProtoZ,go.internal.yoti.com/proto/core/compubapi_v1\272\002\014CompubapiV1_'
  _SIGNEDTIMESTAMP._serialized_start=63
  _SIGNEDTIMESTAMP._serialized_end=251
# @@protoc_insertion_point(module_scope)



from abc import ABCMeta
from abc import abstractmethod

from yoti_python_sdk.utils import YotiSerializable


class SubRequestedCheck(YotiSerializable):
    """
    Requests creation of a SubCheck to be performed on a document
    """

    __metaclass__ = ABCMeta

    @property
    @abstractmethod
    def type(self):
        raise NotImplementedError

    def to_json(self):
        return remove_null_values({"type": self.type, "config": self.config})



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: compubapi_v1/IdentityProfileReport.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import Address_pb2 as compubapi__v1_dot_Address__pb2
from . import DocumentFields_pb2 as compubapi__v1_dot_DocumentFields__pb2
from . import IdentityProfile_pb2 as compubapi__v1_dot_IdentityProfile__pb2
from . import UserProfile_pb2 as compubapi__v1_dot_UserProfile__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(compubapi_v1/IdentityProfileReport.proto\x12\x16yoti.core.compubapi_v1\x1a\x1a\x63ompubapi_v1/Address.proto\x1a!compubapi_v1/DocumentFields.proto\x1a\"compubapi_v1/IdentityProfile.proto\x1a\x1e\x63ompubapi_v1/UserProfile.proto\"\x87\x04\n\x15IdentityProfileReport\x12H\n\x12identity_assertion\x18\x01 \x01(\x0b\x32,.yoti.core.compubapi_v1.IdentityAssertionExt\x12G\n\x13verification_report\x18\x02 \x01(\x0b\x32*.yoti.core.compubapi_v1.VerificationReport\x12,\n\x05proof\x18\x03 \x01(\x0b\x32\x1d.yoti.core.compubapi_v1.Proof\x12K\n\x15\x61uthentication_report\x18\x04 \x01(\x0b\x32,.yoti.core.compubapi_v1.AuthenticationReport\x12H\n\x14profile_match_report\x18\x05 \x01(\x0b\x32*.yoti.core.compubapi_v1.ProfileMatchReport\x12H\n\x14verification_reports\x18\x06 \x03(\x0b\x32*.yoti.core.compubapi_v1.VerificationReport\x12L\n\x16\x61uthentication_reports\x18\x07 \x03(\x0b\x32,.yoti.core.compubapi_v1.AuthenticationReport\"\xac\x01\n\x14IdentityAssertionExt\x12<\n\x0c\x63urrent_name\x18\x01 \x01(\x0b\x32&.yoti.core.compubapi_v1.StructuredName\x12\x15\n\rdate_of_birth\x18\x02 \x01(\t\x12?\n\x0f\x63urrent_address\x18\x03 \x01(\x0b\x32&.yoti.core.compubapi_v1.CurrentAddress\"\x90\x04\n\x12VerificationReport\x12\x11\n\treport_id\x18\x01 \x01(\t\x12\x11\n\ttimestamp\x18\x02 \x01(\t\x12\x12\n\nsubject_id\x18\x03 \x01(\t\x12\\\n\x14\x61\x64\x64ress_verification\x18\x04 \x01(\x0b\x32>.yoti.core.compubapi_v1.VerificationReport.AddressVerification\x12?\n\x0ftrust_framework\x18\x05 \x01(\x0e\x32&.yoti.core.compubapi_v1.TrustFramework\x12J\n\x12schemes_compliance\x18\x06 \x03(\x0b\x32..yoti.core.compubapi_v1.SchemeComplianceReport\x12\x43\n\x11\x61ssurance_process\x18\x07 \x01(\x0b\x32(.yoti.core.compubapi_v1.AssuranceProcess\x12?\n\x08\x65vidence\x18\x08 \x01(\x0b\x32-.yoti.core.compubapi_v1.EvidenceCollectionExt\x1aO\n\x13\x41\x64\x64ressVerification\x12 \n\x18\x63urrent_address_verified\x18\x01 \x01(\x08\x12\x16\n\x0e\x65vidence_links\x18\x02 \x03(\t\"\x8e\x01\n\x19RequirementsNotMetDetails\x12\x14\n\x0c\x66\x61ilure_type\x18\x01 \x01(\t\x12\x15\n\rdocument_type\x18\x02 \x01(\t\x12!\n\x19\x64ocument_country_iso_code\x18\x03 \x01(\t\x12\x10\n\x08\x61udit_id\x18\x04 \x01(\t\x12\x0f\n\x07\x64\x65tails\x18\x05 \x01(\t\"\xde\x01\n\x16SchemeComplianceReport\x12.\n\x06scheme\x18\x01 \x01(\x0b\x32\x1e.yoti.core.compubapi_v1.Scheme\x12\x18\n\x10requirements_met\x18\x02 \x01(\x08\x12!\n\x19requirements_not_met_info\x18\x03 \x01(\t\x12W\n\x1crequirements_not_met_details\x18\x04 \x03(\x0b\x32\x31.yoti.core.compubapi_v1.RequirementsNotMetDetails\"\x9f\x01\n\x10\x43omplianceReport\x12?\n\x0ftrust_framework\x18\x01 \x01(\x0e\x32&.yoti.core.compubapi_v1.TrustFramework\x12J\n\x12schemes_compliance\x18\x02 \x03(\x0b\x32..yoti.core.compubapi_v1.SchemeComplianceReport\"\x87\x01\n\x10\x41ssuranceProcess\x12\x1a\n\x12level_of_assurance\x18\x01 \x01(\t\x12\x0e\n\x06policy\x18\x02 \x01(\t\x12\x11\n\tprocedure\x18\x03 \x01(\t\x12\x34\n\tassurance\x18\x04 \x03(\x0b\x32!.yoti.core.compubapi_v1.Assurance\"I\n\tAssurance\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x16\n\x0e\x63lassification\x18\x02 \x01(\t\x12\x16\n\x0e\x65vidence_links\x18\x03 \x03(\t\"\xe6\x01\n\x15\x45videnceCollectionExt\x12<\n\x04\x66\x61\x63\x65\x18\x01 \x01(\x0b\x32..yoti.core.compubapi_v1.FaceCaptureEvidenceExt\x12>\n\tdocuments\x18\x02 \x03(\x0b\x32+.yoti.core.compubapi_v1.DocumentEvidenceExt\x12O\n\x12\x65lectronic_records\x18\x03 \x03(\x0b\x32\x33.yoti.core.compubapi_v1.ElectronicRecordEvidenceExt\"\xae\x02\n\x16\x46\x61\x63\x65\x43\x61ptureEvidenceExt\x12\x13\n\x0b\x65vidence_id\x18\x01 \x01(\t\x12@\n\x10initial_liveness\x18\x02 \x01(\x0b\x32&.yoti.core.compubapi_v1.PassedLiveness\x12\x45\n\x15last_matched_liveness\x18\x03 \x01(\x0b\x32&.yoti.core.compubapi_v1.PassedLiveness\x12\x15\n\rverifying_org\x18\x04 \x01(\t\x12\x14\n\x0cresource_ids\x18\x05 \x03(\t\x12\x11\n\tcheck_ids\x18\x06 \x03(\t\x12\x19\n\x11user_activity_ids\x18\x07 \x03(\t\x12\x1b\n\x13selfie_attribute_id\x18\x08 \x01(\t\"\xbd\x02\n\x13\x44ocumentEvidenceExt\x12\x13\n\x0b\x65vidence_id\x18\x01 \x01(\t\x12\x11\n\ttimestamp\x18\x02 \x01(\t\x12?\n\x0f\x64ocument_fields\x18\x03 \x01(\x0b\x32&.yoti.core.compubapi_v1.DocumentFields\x12<\n\rpassed_checks\x18\x04 \x03(\x0b\x32%.yoti.core.compubapi_v1.DocumentCheck\x12$\n\x1c\x64ocument_images_attribute_id\x18\x05 \x01(\t\x12\x15\n\rverifying_org\x18\x06 \x01(\t\x12\x14\n\x0cresource_ids\x18\x07 \x03(\t\x12\x11\n\tcheck_ids\x18\x08 \x03(\t\x12\x19\n\x11user_activity_ids\x18\t \x03(\t\"\xf9\x01\n\x1b\x45lectronicRecordEvidenceExt\x12\x13\n\x0b\x65vidence_id\x18\x01 \x01(\t\x12\x11\n\ttimestamp\x18\x02 \x01(\t\x12\x41\n\x10identity_details\x18\x03 \x01(\x0b\x32\'.yoti.core.compubapi_v1.IdentityDetails\x12\x15\n\rverifying_org\x18\x04 \x01(\t\x12\x14\n\x0cprovider_org\x18\x05 \x01(\t\x12\x14\n\x0cresource_ids\x18\x06 \x03(\t\x12\x11\n\tcheck_ids\x18\x07 \x03(\t\x12\x19\n\x11user_activity_ids\x18\x08 \x03(\t\"S\n\x0e\x43urrentAddress\x12\x30\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0b\x32\x1f.yoti.core.compubapi_v1.Address\x12\x0f\n\x07move_in\x18\x02 \x01(\t\"\x9c\x01\n\x14\x41uthenticationReport\x12\x11\n\treport_id\x18\x01 \x01(\t\x12\x11\n\ttimestamp\x18\x02 \x01(\t\x12\r\n\x05level\x18\x03 \x01(\t\x12\x0e\n\x06policy\x18\x04 \x01(\t\x12?\n\x0ftrust_framework\x18\x05 \x01(\x0e\x32&.yoti.core.compubapi_v1.TrustFramework\",\n\x05Proof\x12\x0b\n\x03jws\x18\x01 \x01(\t\x12\x16\n\x0epublic_key_url\x18\x02 \x01(\t\"\x94\x01\n\x11MatchReportResult\x12@\n\x06result\x18\x01 \x01(\x0e\x32\x30.yoti.core.compubapi_v1.MatchReportResult.Result\"=\n\x06Result\x12\r\n\tUNDEFINED\x10\x00\x12\x0c\n\x08NO_MATCH\x10\x01\x12\t\n\x05MATCH\x10\x02\x12\x0b\n\x07PARTIAL\x10\x03\"\x89\x02\n\x12ProfileMatchReport\x12\x46\n\x10provided_profile\x18\x01 \x01(\x0b\x32,.yoti.core.compubapi_v1.IdentityAssertionExt\x12\x37\n\x04name\x18\x02 \x01(\x0b\x32).yoti.core.compubapi_v1.MatchReportResult\x12\x36\n\x03\x64ob\x18\x03 \x01(\x0b\x32).yoti.core.compubapi_v1.MatchReportResult\x12:\n\x07\x61\x64\x64ress\x18\x04 \x01(\x0b\x32).yoti.core.compubapi_v1.MatchReportResultBp\n\x15\x63om.yoti.compubapi_v1B\x1aIdentityProfileReportProtoZ,go.internal.yoti.com/proto/core/compubapi_v1\xba\x02\x0c\x43ompubapiV1_b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'IdentityProfileReport_pb2.py', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\025com.yoti.compubapi_v1B\032IdentityProfileReportProtoZ,go.internal.yoti.com/proto/core/compubapi_v1\272\002\014CompubapiV1_'
  _IDENTITYPROFILEREPORT._serialized_start=200
  _IDENTITYPROFILEREPORT._serialized_end=719
  _IDENTITYASSERTIONEXT._serialized_start=722
  _IDENTITYASSERTIONEXT._serialized_end=894
  _VERIFICATIONREPORT._serialized_start=897
  _VERIFICATIONREPORT._serialized_end=1425
  _VERIFICATIONREPORT_ADDRESSVERIFICATION._serialized_start=1346
  _VERIFICATIONREPORT_ADDRESSVERIFICATION._serialized_end=1425
  _REQUIREMENTSNOTMETDETAILS._serialized_start=1428
  _REQUIREMENTSNOTMETDETAILS._serialized_end=1570
  _SCHEMECOMPLIANCEREPORT._serialized_start=1573
  _SCHEMECOMPLIANCEREPORT._serialized_end=1795
  _COMPLIANCEREPORT._serialized_start=1798
  _COMPLIANCEREPORT._serialized_end=1957
  _ASSURANCEPROCESS._serialized_start=1960
  _ASSURANCEPROCESS._serialized_end=2095
  _ASSURANCE._serialized_start=2097
  _ASSURANCE._serialized_end=2170
  _EVIDENCECOLLECTIONEXT._serialized_start=2173
  _EVIDENCECOLLECTIONEXT._serialized_end=2403
  _FACECAPTUREEVIDENCEEXT._serialized_start=2406
  _FACECAPTUREEVIDENCEEXT._serialized_end=2708
  _DOCUMENTEVIDENCEEXT._serialized_start=2711
  _DOCUMENTEVIDENCEEXT._serialized_end=3028
  _ELECTRONICRECORDEVIDENCEEXT._serialized_start=3031
  _ELECTRONICRECORDEVIDENCEEXT._serialized_end=3280
  _CURRENTADDRESS._serialized_start=3282
  _CURRENTADDRESS._serialized_end=3365
  _AUTHENTICATIONREPORT._serialized_start=3368
  _AUTHENTICATIONREPORT._serialized_end=3524
  _PROOF._serialized_start=3526
  _PROOF._serialized_end=3570
  _MATCHREPORTRESULT._serialized_start=3573
  _MATCHREPORTRESULT._serialized_end=3721
  _MATCHREPORTRESULT_RESULT._serialized_start=3660
  _MATCHREPORTRESULT_RESULT._serialized_end=3721
  _PROFILEMATCHREPORT._serialized_start=3724
  _PROFILEMATCHREPORT._serialized_end=3989
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from yoti_python_sdk.doc_scan.session.retrieve.media_response import MediaResponse


class FrameResponse(object):
    """
    Represents a frame of a resource
    """

    def __init__(self, data=None):
        """
        :param data: the data to parse
        :type data: dict or None
        """
        if data is None:
            data = dict()

        self.__media = MediaResponse(data["media"]) if "media" in data.keys() else None

    @property
    def media(self):
        """
        Returns the media associated with the frame

        :return: the media
        :rtype: MediaResponse or None
        """
        return self.__media



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from yoti_python_sdk.doc_scan.constants import ID_DOCUMENT_COMPARISON
from yoti_python_sdk.utils import YotiSerializable
from .requested_check import RequestedCheck


class RequestedIDDocumentComparisonCheckConfig(YotiSerializable):
    """
    The configuration applied when creating a Document Comparison Check
    """

    def to_json(self):
        return {}


class RequestedIDDocumentComparisonCheck(RequestedCheck):
    """
    Requests creation of a Document Comparison Check
    """

    def __init__(self, config):
        """
        :param config: the requested document Comparison check configuration
        :type config: RequestedIDDocumentComparisonCheckConfig
        """
        self.__config = config

    @property
    def type(self):
        return ID_DOCUMENT_COMPARISON

    @property
    def config(self):
        return self.__config


class RequestedIDDocumentComparisonCheckBuilder(object):
    """
    Builder to assist creation of :class:`RequestedIDDocumentComparisonCheck`
    """

    @staticmethod
    def build():
        config = RequestedIDDocumentComparisonCheckConfig()
        return RequestedIDDocumentComparisonCheck(config)



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from .media_response import MediaResponse
from .frame_response import FrameResponse


class PageResponse(object):
    """
    Represents information about an uploaded document Page
    """

    def __init__(self, data=None):
        """
        :param data: the data to parse
        :type data: dict or None
        """
        if data is None:
            data = dict()

        self.__capture_method = (
            data["capture_method"] if "capture_method" in data.keys() else None
        )
        self.__media = MediaResponse(data["media"]) if "media" in data.keys() else None
        self.__frames = [FrameResponse(frame) for frame in data.get("frames", [])]

    @property
    def capture_method(self):
        """
        The capture method that was used for the Page

        :return: the capture method
        :rtype: str or None
        """
        return self.__capture_method

    @property
    def media(self):
        """
        The media associated with the Page

        :return: the media
        :rtype: MediaResponse or None
        """
        return self.__media

    @property
    def frames(self):
        """
        Returns the list of associated frames

        :return: the frames
        :rtype: list[FrameResponse]
        """
        return self.__frames



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sharepubapi_v1/ThirdPartyAttribute.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import IssuingAttributes_pb2 as sharepubapi__v1_dot_IssuingAttributes__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(sharepubapi_v1/ThirdPartyAttribute.proto\x12\x18yoti.core.sharepubapi_v1\x1a&sharepubapi_v1/IssuingAttributes.proto\"v\n\x13ThirdPartyAttribute\x12\x16\n\x0eissuance_token\x18\x01 \x01(\x0c\x12G\n\x12issuing_attributes\x18\x02 \x01(\x0b\x32+.yoti.core.sharepubapi_v1.IssuingAttributesBt\n\x17\x63om.yoti.sharepubapi_v1B\x18ThirdPartyAttributeProtoZ.go.internal.yoti.com/proto/core/sharepubapi_v1\xba\x02\x0eSharepubapiV1_b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ThirdPartyAttribute_pb2.py', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.yoti.sharepubapi_v1B\030ThirdPartyAttributeProtoZ.go.internal.yoti.com/proto/core/sharepubapi_v1\272\002\016SharepubapiV1_'
  _THIRDPARTYATTRIBUTE._serialized_start=110
  _THIRDPARTYATTRIBUTE._serialized_end=228
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-

from yoti_python_sdk.doc_scan.session.create.filter.document_filter import DocumentFilter
from yoti_python_sdk.utils import YotiSerializable
from .sub_check import SubRequestedCheck


class IssuingAuthoritySubCheck(SubRequestedCheck):
    """
    Requests creation of an Issuing Authority Sub Check.
    """

    def __init__(self, filter=None):
        self._filter = filter

    @property
    def requested(self):
        return True

    @property
    def filter(self):
        return self._filter


class IssuingAuthoritySubCheckBuilder:
    """
    Builder for Issuing Authority Sub Check.
    """
    def __init__(self):
        self._filter = None

    def with_filter(self, filter):
        if not issubclass(type(filter), DocumentFilter):
            raise ValueError('invalid filter')

        self._filter = filter

        return self

    def build(self):
        return IssuingAuthoritySubCheck(filter=self._filter)



# -*- coding: utf-8 -*-

from yoti_python_sdk import date_parser
import base64


class Definition(object):
    def __init__(self, name):
        self.__name = name

    @property
    def name(self):
        return self.__name


class AttributeIssuanceDetails(object):
    def __init__(self, data_entry):
        self.__token = base64.b64encode(data_entry.issuance_token)
        self.__expiry_date = date_parser.datetime_with_microsecond(
            data_entry.issuing_attributes.expiry_date
        )
        self.__attributes = [
            Definition(a.name) for a in data_entry.issuing_attributes.definitions
        ]

    @property
    def token(self):
        return self.__token

    @property
    def attributes(self):
        return self.__attributes

    @property
    def expiry_date(self):
        return self.__expiry_date



# -*- coding: utf-8 -*-
from __future__ import unicode_literals


class BreakdownResponse(object):
    """
    Represents one breakdown item for a given check
    """

    def __init__(self, data):
        """
        :param data: the data to parse
        :type data: dict
        """
        self.__sub_check = data.get("sub_check", None)
        self.__result = data.get("result", None)
        self.__details = [DetailsResponse(detail) for detail in data.get("details", [])]

    @property
    def sub_check(self):
        """
        The sub check value for the breakdown

        :return: the sub check value
        :rtype: str or None
        """
        return self.__sub_check

    @property
    def result(self):
        """
        The result of the sub check

        :return: the result
        :rtype: str or None
        """
        return self.__result

    @property
    def details(self):
        """
        The details of the sub check

        :return: the details
        :rtype: list[DetailsResponse]
        """
        return self.__details


class DetailsResponse(object):
    """
    Represents a specific detail for a breakdown
    """

    def __init__(self, data):
        self.__name = data.get("name", None)
        self.__value = data.get("value", None)

    @property
    def name(self):
        """
        The name of the details item

        :return: the name
        :rtype: str or None
        """
        return self.__name

    @property
    def value(self):
        """
        The value of the details item

        :return: the value
        :rtype: str or None
        """
        return self.__value



# -*- coding: utf-8 -*-

from datetime import datetime, date
import logging
import re


ERROR_PARSING_DATE = "Error parsing date"


def from_iso_format(string):
    parts = [int(a) for a in string.split("-")]

    if len(parts) != 3:
        raise ValueError

    return date(parts[0], parts[1], parts[2])


def datetime_with_microsecond(string):
    # Python2 does not have a way of parsing date formats.
    # Deprecate this once Python2 support is dropped.
    time_split = re.split("[^0-9]", string)
    parts = len(time_split)
    if parts <= 6:
        if logging.getLogger().propagate:
            logging.warning(ERROR_PARSING_DATE)
        return None

    try:
        year = int(time_split[0])
        month = int(time_split[1])
        day = int(time_split[2])
        hour = int(time_split[3])
        minute = int(time_split[4])
        second = int(time_split[5])
        microsecond = int(round(float("0." + time_split[6]) * 1e6))
        return datetime(year, month, day, hour, minute, second, microsecond)
    except ValueError:
        if logging.getLogger().propagate:
            logging.warning(ERROR_PARSING_DATE)
        return None



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

import re

from yoti_python_sdk import config

from .wanted_attribute_builder import WantedAttributeBuilder


class DynamicPolicyBuilder(object):
    """
    Builder for DynamicPolicy
    """

    SELFIE_AUTH_TYPE = 1
    PIN_AUTH_TYPE = 2

    def __init__(self):
        self.__wanted_attributes = {}
        self.__wanted_auth_types = {}
        self.__is_wanted_remember_me = False

    def with_wanted_attribute(self, wanted_attribute):
        """
        @param wanted_attribute
        """
        key = (
            wanted_attribute["derivation"]
            if wanted_attribute.get("derivation", False)
            else wanted_attribute["name"]
        )
        self.__wanted_attributes[key] = wanted_attribute
        return self

    def __attribute_keyword_parser(self, attributeBuilder, **kwargs):
        constraints = kwargs.get("constraints", False)
        if constraints:
            attributeBuilder.with_constraint(constraints)

        accept_self_asserted = kwargs.get("accept_self_asserted", None)
        if accept_self_asserted is not None:
            attributeBuilder.with_accept_self_asserted(accept_self_asserted)

    def with_wanted_attribute_by_name(self, wanted_name, **kwargs):
        """
        @param wanted_name The name of the attribute to include
        """
        attributeBuilder = WantedAttributeBuilder().with_name(wanted_name)
        self.__attribute_keyword_parser(attributeBuilder, **kwargs)

        return self.with_wanted_attribute(attributeBuilder.build())

    def with_family_name(self, **kwargs):
        return self.with_wanted_attribute_by_name(
            config.ATTRIBUTE_FAMILY_NAME, **kwargs
        )

    def with_given_names(self, **kwargs):
        return self.with_wanted_attribute_by_name(
            config.ATTRIBUTE_GIVEN_NAMES, **kwargs
        )

    def with_full_name(self, **kwargs):
        return self.with_wanted_attribute_by_name(config.ATTRIBUTE_FULL_NAME, **kwargs)

    def with_date_of_birth(self, **kwargs):
        return self.with_wanted_attribute_by_name(
            config.ATTRIBUTE_DATE_OF_BIRTH, **kwargs
        )

    def with_age_derived_attribute(self, derivation, **kwargs):
        attributeBuilder = (
            WantedAttributeBuilder()
            .with_name(config.ATTRIBUTE_DATE_OF_BIRTH)
            .with_derivation(derivation)
        )
        self.__attribute_keyword_parser(attributeBuilder, **kwargs)
        return self.with_wanted_attribute(attributeBuilder.build())

    def with_age_over(self, age, **kwargs):
        assert self.__is_number(age)
        return self.with_age_derived_attribute(
            config.ATTRIBUTE_AGE_OVER + str(age), **kwargs
        )

    def with_age_under(self, age, **kwargs):
        assert self.__is_number(age)
        return self.with_age_derived_attribute(
            config.ATTRIBUTE_AGE_UNDER + str(age), **kwargs
        )

    def with_gender(self, **kwargs):
        return self.with_wanted_attribute_by_name(config.ATTRIBUTE_GENDER, **kwargs)

    def with_postal_address(self, **kwargs):
        return self.with_wanted_attribute_by_name(
            config.ATTRIBUTE_POSTAL_ADDRESS, **kwargs
        )

    def with_structured_postal_address(self, **kwargs):
        return self.with_wanted_attribute_by_name(
            config.ATTRIBUTE_STRUCTURED_POSTAL_ADDRESS, **kwargs
        )

    def with_nationality(self, **kwargs):
        return self.with_wanted_attribute_by_name(
            config.ATTRIBUTE_NATIONALITY, **kwargs
        )

    def with_phone_number(self, **kwargs):
        return self.with_wanted_attribute_by_name(
            config.ATTRIBUTE_PHONE_NUMBER, **kwargs
        )

    def with_selfie(self, **kwargs):
        return self.with_wanted_attribute_by_name(config.ATTRIBUTE_SELFIE, **kwargs)

    def with_email(self, **kwargs):
        return self.with_wanted_attribute_by_name(
            config.ATTRIBUTE_EMAIL_ADDRESS, **kwargs
        )

    def with_document_details(self, **kwargs):
        return self.with_wanted_attribute_by_name(
            config.ATTRIBUTE_DOCUMENT_DETAILS, **kwargs
        )

    def with_document_images(self, **kwargs):
        return self.with_wanted_attribute_by_name(
            config.ATTRIBUTE_DOCUMENT_IMAGES, **kwargs
        )

    """
    @param wanted_auth_type
    """

    def with_wanted_auth_type(self, wanted_auth_type, wanted=True):
        self.__wanted_auth_types[wanted_auth_type] = wanted
        return self

    def with_selfie_auth(self, wanted=True):
        return self.with_wanted_auth_type(self.SELFIE_AUTH_TYPE, wanted)

    def with_pin_auth(self, wanted=True):
        return self.with_wanted_auth_type(self.PIN_AUTH_TYPE, wanted)

    """
    @param wanted
    """

    def with_wanted_remember_me(self, wanted=True):
        self.__is_wanted_remember_me = wanted
        return self

    def build(self):
        return {
            "wanted": list(self.__wanted_attributes.values()),
            "wanted_auth_types": [
                auth for (auth, b) in self.__wanted_auth_types.items() if b
            ],
            "wanted_remember_me": self.__is_wanted_remember_me,
        }

    def __is_number(self, num):
        return re.match(r"^\d+$", str(num)) is not None



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: compubapi_v1/ChipInfo.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x63ompubapi_v1/ChipInfo.proto\x12\x0c\x63ompubapi_v1\"d\n\x08\x43hipInfo\x12)\n\x04type\x18\x01 \x01(\x0e\x32\x1b.compubapi_v1.ChipInfo.Type\x12\n\n\x02id\x18\x02 \x01(\t\"!\n\x04Type\x12\r\n\tUNDEFINED\x10\x00\x12\n\n\x06MULTOS\x10\x01\x42T\n\x15\x63om.yoti.compubapi_v1Z,go.internal.yoti.com/proto/core/compubapi_v1\xba\x02\x0c\x43ompubapiV1_b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ChipInfo_pb2.py', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\025com.yoti.compubapi_v1Z,go.internal.yoti.com/proto/core/compubapi_v1\272\002\014CompubapiV1_'
  _CHIPINFO._serialized_start=45
  _CHIPINFO._serialized_end=145
  _CHIPINFO_TYPE._serialized_start=112
  _CHIPINFO_TYPE._serialized_end=145
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
import logging

from yoti_python_sdk import attribute_parser, config, multivalue, document_details
from yoti_python_sdk.anchor import Anchor
from yoti_python_sdk.attribute import Attribute
from yoti_python_sdk.image import Image
from yoti_python_sdk.age_verification import AgeVerification


class BaseProfile(object):
    def __init__(self, profile_attributes):
        self.attributes = {}
        self.verifications = None

        if profile_attributes:
            for field in profile_attributes:
                try:
                    value = attribute_parser.value_based_on_content_type(
                        field.value, field.content_type
                    )

                    # this will be removed in v3.0.0, so selfie also returns an Image object
                    if field.content_type in Image.allowed_types():
                        if field.name == config.ATTRIBUTE_SELFIE:
                            value = field.value

                    if field.name == config.ATTRIBUTE_DOCUMENT_IMAGES:
                        value = multivalue.filter_values(value, Image)
                    if field.name == config.ATTRIBUTE_DOCUMENT_DETAILS:
                        value = document_details.DocumentDetails(value)

                    anchors = Anchor().parse_anchors(field.anchors)

                    self.attributes[field.name] = Attribute(field.name, value, anchors)

                except ValueError as ve:
                    if logging.getLogger().propagate:
                        logging.warning(ve)
                except Exception as exc:
                    if logging.getLogger().propagate:
                        logging.warning(
                            "Error parsing profile attribute:{0}, exception: {1} - {2}".format(
                                field.name, type(exc).__name__, exc
                            )
                        )

    def get_attribute(self, attribute_name):
        """
        retrieves an attribute based on its name
        :param attribute_name:
        :return: Attribute
        """
        if attribute_name in self.attributes:
            return self.attributes.get(attribute_name)
        else:
            return None


class Profile(BaseProfile):
    def __init__(self, profile_attributes):
        super(Profile, self).__init__(profile_attributes)
        self.ensure_postal_address()

    @property
    def date_of_birth(self):
        """date_of_birth represents the user's date of birth as a string.
        Will be changed to return a datetime in v3.0.0.
        Will be None if not provided by Yoti.
        :return: Attribute(str)
        """
        return self.get_attribute(config.ATTRIBUTE_DATE_OF_BIRTH)

    @property
    def family_name(self):
        """family_name represents the user's family name. This will be None if not provided by Yoti.
        :return: Attribute(str)
        """
        return self.get_attribute(config.ATTRIBUTE_FAMILY_NAME)

    @property
    def given_names(self):
        """given_names represents the user's given names. This will be None if not provided by Yoti.
        :return: Attribute(str)
        """
        return self.get_attribute(config.ATTRIBUTE_GIVEN_NAMES)

    @property
    def full_name(self):
        """full_name represents the user's full name.
        If family_name and given_names are present, the value will be equal to the string 'given_names + " " + family_name'.
        Will be None if not provided by Yoti.
        :return: Attribute(str)
        """
        return self.get_attribute(config.ATTRIBUTE_FULL_NAME)

    @property
    def gender(self):
        """gender corresponds to the gender in the registered document.
        The value will be one of the strings "MALE", "FEMALE", "TRANSGENDER" or "OTHER".
        Will be None if not provided by Yoti.
        :return: Attribute(str)
        """
        return self.get_attribute(config.ATTRIBUTE_GENDER)

    @property
    def nationality(self):
        """nationality corresponds to the nationality in the passport.
        The value is an ISO-3166-1 alpha-3 code with ICAO9303 (passport) extensions.
        Will be None if not provided by Yoti.
        :return: Attribute(str)
        """
        return self.get_attribute(config.ATTRIBUTE_NATIONALITY)

    @property
    def email_address(self):
        """email_address represents the user's email address. This will be None if not provided by Yoti.
        :return: Attribute(str)
        """
        return self.get_attribute(config.ATTRIBUTE_EMAIL_ADDRESS)

    @property
    def phone_number(self):
        """phone_number represents the user's mobile phone number. This will be None if not provided by Yoti.
        :return: Attribute(str)
        """
        return self.get_attribute(config.ATTRIBUTE_PHONE_NUMBER)

    @property
    def postal_address(self):
        """postal_address represents the user's address. This will be None if not provided by Yoti.
        :return: Attribute(str)
        """
        return self.get_attribute(config.ATTRIBUTE_POSTAL_ADDRESS)

    @property
    def selfie(self):
        """selfie is a photograph of the user. Will be None if not provided by Yoti.
        :return: Attribute(image)
        """
        return self.get_attribute(config.ATTRIBUTE_SELFIE)

    @property
    def structured_postal_address(self):
        """structured_postal_address represents the user's address represented as an OrderedDict.
        This will be None if not provided by Yoti.
        :return: Attribute(OrderedDict)
        """
        return self.get_attribute(config.ATTRIBUTE_STRUCTURED_POSTAL_ADDRESS)

    @property
    def document_images(self):
        """document_images returns a tuple of document images cropped from the image in the capture page.
        There can be multiple images as per the number of regions in the capture in this attribute.
        Will be None if not provided by Yoti.
        :return: Attribute(tuple(image))
        """
        return self.get_attribute(config.ATTRIBUTE_DOCUMENT_IMAGES)

    @property
    def document_details(self):
        return self.get_attribute(config.ATTRIBUTE_DOCUMENT_DETAILS)

    def get_age_verifications(self):
        self.__find_all_age_verifications()
        return [self.verifications[key] for key in self.verifications.keys()]

    def find_age_over_verification(self, age):
        self.__find_all_age_verifications()
        if config.ATTRIBUTE_AGE_OVER + str(age) in self.verifications:
            return self.verifications[config.ATTRIBUTE_AGE_OVER + str(age)]
        return None

    def find_age_under_verification(self, age):
        self.__find_all_age_verifications()
        if (config.ATTRIBUTE_AGE_UNDER + str(age)) in self.verifications:
            return self.verifications[config.ATTRIBUTE_AGE_UNDER + str(age)]
        return None

    def __find_all_age_verifications(self):
        if self.verifications is None:
            self.verifications = {}
            for key in self.attributes:
                attribute = self.attributes[key]
                if hasattr(
                    attribute, "name"
                ):  # This will be changed in v3 as selfie will be an object rather than a string
                    if (
                        config.ATTRIBUTE_AGE_OVER in attribute.name
                        or config.ATTRIBUTE_AGE_UNDER in attribute.name
                    ):
                        self.verifications[attribute.name] = AgeVerification(attribute)

    def ensure_postal_address(self):
        if (
            config.ATTRIBUTE_POSTAL_ADDRESS not in self.attributes
            and config.ATTRIBUTE_STRUCTURED_POSTAL_ADDRESS in self.attributes
        ):
            structured_postal_address = self.attributes[
                config.ATTRIBUTE_STRUCTURED_POSTAL_ADDRESS
            ]

            if config.KEY_FORMATTED_ADDRESS in structured_postal_address.value:
                formatted_address = structured_postal_address.value[
                    config.KEY_FORMATTED_ADDRESS
                ]
                self.attributes[config.ATTRIBUTE_POSTAL_ADDRESS] = Attribute(
                    config.ATTRIBUTE_POSTAL_ADDRESS,
                    formatted_address,
                    structured_postal_address.anchors,
                )


class ApplicationProfile(BaseProfile):
    def __init__(self, profile_attributes):
        super(ApplicationProfile, self).__init__(profile_attributes)

    @property
    def application_name(self):
        """
        application_name is the name of the application set in Yoti Hub
        :return: Attribute(str)
        """
        return self.get_attribute(config.ATTRIBUTE_APPLICATION_NAME)

    @property
    def application_url(self):
        """
        application_url is the url of the application set in Yoti Hub
        :return: Attribute(str)
        """
        return self.get_attribute(config.ATTRIBUTE_APPLICATION_URL)

    @property
    def application_logo(self):
        """
        application_logo is the Image of the application logo set in Yoti Hub
        :return: Attribute(str)
        """
        return self.get_attribute(config.ATTRIBUTE_APPLICATION_LOGO)

    @property
    def application_receipt_bg_color(self):
        """
        application_receipt_bg_color is the background color of the application set in Yoti Hub
        :return: Attribute(str)
        """
        return self.get_attribute(config.ATTRIBUTE_APPLICATION_RECEIPT_BGCOLOR)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: attrpubapi_v1/List.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import Attribute_pb2 as attrpubapi__v1_dot_Attribute__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18\x61ttrpubapi_v1/List.proto\x12\x17yoti.core.attrpubapi_v1\x1a\x1d\x61ttrpubapi_v1/Attribute.proto\"]\n\x0e\x41ttributeAndId\x12\x35\n\tattribute\x18\x01 \x01(\x0b\x32\".yoti.core.attrpubapi_v1.Attribute\x12\x14\n\x0c\x61ttribute_id\x18\x02 \x01(\x0c\"\\\n\x12\x41ttributeAndIdList\x12\x46\n\x15\x61ttribute_and_id_list\x18\x01 \x03(\x0b\x32\'.yoti.core.attrpubapi_v1.AttributeAndId\"G\n\rAttributeList\x12\x36\n\nattributes\x18\x01 \x03(\x0b\x32\".yoti.core.attrpubapi_v1.AttributeBk\n\x16\x63om.yoti.attrpubapi_v1B\x12\x41ttributeListProtoZ-go.internal.yoti.com/proto/core/attrpubapi_v1\xba\x02\rAttrpubapiV1_b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'List_pb2.py', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026com.yoti.attrpubapi_v1B\022AttributeListProtoZ-go.internal.yoti.com/proto/core/attrpubapi_v1\272\002\rAttrpubapiV1_'
  _ATTRIBUTEANDID._serialized_start=84
  _ATTRIBUTEANDID._serialized_end=177
  _ATTRIBUTEANDIDLIST._serialized_start=179
  _ATTRIBUTEANDIDLIST._serialized_end=271
  _ATTRIBUTELIST._serialized_start=273
  _ATTRIBUTELIST._serialized_end=344
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: attrpubapi_v1/AttributeChange.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import Refresh_pb2 as attrpubapi__v1_dot_Refresh__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#attrpubapi_v1/AttributeChange.proto\x12\x17yoti.core.attrpubapi_v1\x1a\x1b\x61ttrpubapi_v1/Refresh.proto\"j\n\x0f\x41ttributeChange\x12?\n\x06status\x18\x01 \x01(\x0e\x32/.yoti.core.attrpubapi_v1.RefreshResponse.Status\x12\x16\n\x0e\x61ttribute_name\x18\x02 \x01(\tBm\n\x16\x63om.yoti.attrpubapi_v1B\x14\x41ttributeChangeProtoZ-go.internal.yoti.com/proto/core/attrpubapi_v1\xba\x02\rAttrpubapiV1_b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'AttributeChange_pb2.py', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026com.yoti.attrpubapi_v1B\024AttributeChangeProtoZ-go.internal.yoti.com/proto/core/attrpubapi_v1\272\002\rAttrpubapiV1_'
  _ATTRIBUTECHANGE._serialized_start=93
  _ATTRIBUTECHANGE._serialized_end=199
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
from __future__ import unicode_literals


class TransactionalFlowExtensionBuilder(object):
    TRANSACTIONAL_FLOW = "TRANSACTIONAL_FLOW"

    def __init__(self):
        self.__extension = {}
        self.__extension["type"] = self.TRANSACTIONAL_FLOW

    def with_content(self, content):
        """
        @param content The extension content
        """
        self.__extension["content"] = content
        return self

    def build(self):
        """
        @return Dictionary representation of an extension
        """
        return self.__extension.copy()



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from yoti_python_sdk.doc_scan import constants
from yoti_python_sdk.utils import YotiSerializable, remove_null_values
from .requested_task import RequestedTask


class RequestedSupplementaryDocTextExtractionTaskConfig(YotiSerializable):
    def __init__(self, manual_check):
        """
        :param manual_check: the manual check value
        :type manual_check: str
        """
        self.__manual_check = manual_check

    @property
    def manual_check(self):
        """
        Describes the manual fallback behaviour applied to each Task

        :return: the manual check value
        """
        return self.__manual_check

    def to_json(self):
        return remove_null_values({"manual_check": self.manual_check})


class RequestedSupplementaryDocTextExtractionTask(RequestedTask):
    """
    Builder to assist creation of :class:`RequestedSupplementaryDocTextExtractionTask`
    """

    def __init__(self, config):
        """
        :param config: the text extraction task configuration
        :type config: RequestedSupplementaryDocTextExtractionTaskConfig
        """
        self.__config = config

    @property
    def type(self):
        return constants.SUPPLEMENTARY_DOCUMENT_TEXT_DATA_EXTRACTION

    @property
    def config(self):
        return self.__config


class RequestedSupplementaryDocTextExtractionTaskBuilder(object):
    """
    Builder to assist creation of :class:`RequestedSupplementaryDocTextExtractionTask`
    """

    def __init__(self):
        self.__manual_check = None

    def with_manual_check_always(self):
        """
        Sets the manual check value to be "ALWAYS"

        :return: the builder
        :rtype: RequestedSupplementaryDocTextExtractionTaskBuilder
        """
        self.__manual_check = constants.ALWAYS
        return self

    def with_manual_check_fallback(self):
        """
        Sets the manual check value to be "FALLBACK"

        :return: the builder
        :rtype: RequestedSupplementaryDocTextExtractionTaskBuilder
        """
        self.__manual_check = constants.FALLBACK
        return self

    def with_manual_check_never(self):
        """
        Sets the manual check value to be "NEVER"

        :return: the builder
        :rtype: RequestedSupplementaryDocTextExtractionTaskBuilder
        """
        self.__manual_check = constants.NEVER
        return self

    def build(self):
        config = RequestedSupplementaryDocTextExtractionTaskConfig(self.__manual_check)
        return RequestedSupplementaryDocTextExtractionTask(config)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sharepubapi_v1/Policy.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yoti_python_sdk.protobuf.compubapi_v1 import IdentityProfile_pb2 as compubapi__v1_dot_IdentityProfile__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bsharepubapi_v1/Policy.proto\x12\x18yoti.core.sharepubapi_v1\x1a\"compubapi_v1/IdentityProfile.proto\"\x83\x0c\n\x06Policy\x12:\n\x06wanted\x18\x01 \x03(\x0b\x32*.yoti.core.sharepubapi_v1.Policy.Attribute\x12\x39\n\x05given\x18\x02 \x03(\x0b\x32*.yoti.core.sharepubapi_v1.Policy.Attribute\x12\x1a\n\x12wanted_remember_me\x18\x03 \x01(\x08\x12\x19\n\x11given_remember_me\x18\x04 \x01(\x08\x12\x18\n\x10given_auth_types\x18\x05 \x03(\x05\x12\x19\n\x11wanted_auth_types\x18\x06 \x03(\x05\x12#\n\x1bwanted_remember_me_optional\x18\x07 \x01(\x08\x12M\n\x10identity_profile\x18\x08 \x01(\x0b\x32\x33.yoti.core.compubapi_v1.IdentityProfileRequirements\x12S\n\x13verification_report\x18\t \x01(\x0b\x32\x36.yoti.core.compubapi_v1.VerificationReportRequirements\x12^\n\x19\x61\x64vanced_identity_profile\x18\x0b \x01(\x0b\x32;.yoti.core.compubapi_v1.AdvancedIdentityProfileRequirements\x1a\x8e\x01\n\nConstraint\x12>\n\x04type\x18\x01 \x01(\x0e\x32\x30.yoti.core.sharepubapi_v1.Policy.Constraint.Type\x12\x12\n\nconstraint\x18\x02 \x01(\x0c\",\n\x04Type\x12\r\n\tUNDEFINED\x10\x00\x12\t\n\x05VALUE\x10\x01\x12\n\n\x06SOURCE\x10\x02\x1a\x8b\x01\n\x0fValueConstraint\x12\x43\n\x04type\x18\x01 \x01(\x0e\x32\x35.yoti.core.sharepubapi_v1.Policy.ValueConstraint.Type\x12\x12\n\nconstraint\x18\x02 \x01(\x0c\"\x1f\n\x04Type\x12\r\n\tUNDEFINED\x10\x00\x12\x08\n\x04\x44\x41TE\x10\x01\x1a\xde\x01\n\x0e\x44\x61teConstraint\x12\x44\n\x02op\x18\x01 \x01(\x0e\x32\x38.yoti.core.sharepubapi_v1.Policy.DateConstraint.Operator\x12\x0c\n\x04\x64\x61te\x18\x02 \x01(\t\x12;\n\x06offset\x18\x03 \x01(\x0b\x32+.yoti.core.sharepubapi_v1.Policy.DateOffset\";\n\x08Operator\x12\r\n\tUNDEFINED\x10\x00\x12\n\n\x06\x42\x45\x46ORE\x10\x01\x12\t\n\x05\x41\x46TER\x10\x02\x12\t\n\x05\x45QUAL\x10\x03\x1a*\n\nDateOffset\x12\x0c\n\x04\x64\x61ys\x18\x01 \x01(\x05\x12\x0e\n\x06months\x18\x02 \x01(\x05\x1a(\n\x06\x41nchor\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08sub_type\x18\x02 \x01(\t\x1a\x63\n\x0ePreferenceList\x12\x38\n\x07\x61nchors\x18\x01 \x03(\x0b\x32\'.yoti.core.sharepubapi_v1.Policy.Anchor\x12\x17\n\x0fsoft_preference\x18\x02 \x01(\x08\x1a^\n\x10SourceConstraint\x12J\n\x11preferred_sources\x18\x01 \x01(\x0b\x32/.yoti.core.sharepubapi_v1.Policy.PreferenceList\x1a\xcb\x01\n\tAttribute\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07\x61nchors\x18\x02 \x03(\t\x12\x12\n\nderivation\x18\x03 \x01(\t\x12\x10\n\x08optional\x18\x04 \x01(\x08\x12\x1c\n\x14\x61\x63\x63\x65pt_self_asserted\x18\x05 \x01(\x08\x12@\n\x0b\x63onstraints\x18\x06 \x03(\x0b\x32+.yoti.core.sharepubapi_v1.Policy.Constraint\x12\x19\n\x11\x61lternative_names\x18\x07 \x03(\tJ\x04\x08\n\x10\x0b\x42g\n\x17\x63om.yoti.sharepubapi_v1B\x0bPolicyProtoZ.go.internal.yoti.com/proto/core/sharepubapi_v1\xba\x02\x0eSharepubapiV1_b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'Policy_pb2.py', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.yoti.sharepubapi_v1B\013PolicyProtoZ.go.internal.yoti.com/proto/core/sharepubapi_v1\272\002\016SharepubapiV1_'
  _POLICY._serialized_start=94
  _POLICY._serialized_end=1633
  _POLICY_CONSTRAINT._serialized_start=629
  _POLICY_CONSTRAINT._serialized_end=771
  _POLICY_CONSTRAINT_TYPE._serialized_start=727
  _POLICY_CONSTRAINT_TYPE._serialized_end=771
  _POLICY_VALUECONSTRAINT._serialized_start=774
  _POLICY_VALUECONSTRAINT._serialized_end=913
  _POLICY_VALUECONSTRAINT_TYPE._serialized_start=882
  _POLICY_VALUECONSTRAINT_TYPE._serialized_end=913
  _POLICY_DATECONSTRAINT._serialized_start=916
  _POLICY_DATECONSTRAINT._serialized_end=1138
  _POLICY_DATECONSTRAINT_OPERATOR._serialized_start=1079
  _POLICY_DATECONSTRAINT_OPERATOR._serialized_end=1138
  _POLICY_DATEOFFSET._serialized_start=1140
  _POLICY_DATEOFFSET._serialized_end=1182
  _POLICY_ANCHOR._serialized_start=1184
  _POLICY_ANCHOR._serialized_end=1224
  _POLICY_PREFERENCELIST._serialized_start=1226
  _POLICY_PREFERENCELIST._serialized_end=1325
  _POLICY_SOURCECONSTRAINT._serialized_start=1327
  _POLICY_SOURCECONSTRAINT._serialized_end=1421
  _POLICY_ATTRIBUTE._serialized_start=1424
  _POLICY_ATTRIBUTE._serialized_end=1627
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sharepubapi_v1/SharingNotificationPush.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import Policy_pb2 as sharepubapi__v1_dot_Policy__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,sharepubapi_v1/SharingNotificationPush.proto\x12\x18yoti.core.sharepubapi_v1\x1a\x1bsharepubapi_v1/Policy.proto\"\x90\x01\n\x13SharingNotification\x12\x15\n\rsharing_token\x18\x01 \x01(\x0c\x12\x1a\n\x12notification_token\x18\x02 \x01(\x0c\x12\x14\n\x0csession_data\x18\x03 \x01(\t\x12\x30\n\x06policy\x18\x04 \x01(\x0b\x32 .yoti.core.sharepubapi_v1.PolicyBt\n\x17\x63om.yoti.sharepubapi_v1B\x18SharingNotificationProtoZ.go.internal.yoti.com/proto/core/sharepubapi_v1\xba\x02\x0eSharepubapiV1_b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'SharingNotificationPush_pb2.py', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.yoti.sharepubapi_v1B\030SharingNotificationProtoZ.go.internal.yoti.com/proto/core/sharepubapi_v1\272\002\016SharepubapiV1_'
  _SHARINGNOTIFICATION._serialized_start=104
  _SHARINGNOTIFICATION._serialized_end=248
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: compubapi_v1/MRZ.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16\x63ompubapi_v1/MRZ.proto\x12\x16yoti.core.compubapi_v1\"\x92\x01\n\x03MRZ\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\r\n\x05line1\x18\x02 \x01(\t\x12\r\n\x05line2\x18\x03 \x01(\t\x12\r\n\x05line3\x18\x04 \x01(\t\"P\n\x04Type\x12\r\n\tUNDEFINED\x10\x00\x12\x07\n\x03TD1\x10\x01\x12\x07\n\x03TD3\x10\x02\x12\n\n\x06RUS_ID\x10\x03\x12\x07\n\x03TD2\x10\x04\x12\x12\n\rUNCATEGORISED\x10\xe8\x07\x42T\n\x15\x63om.yoti.compubapi_v1Z,go.internal.yoti.com/proto/core/compubapi_v1\xba\x02\x0c\x43ompubapiV1_b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'MRZ_pb2.py', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\025com.yoti.compubapi_v1Z,go.internal.yoti.com/proto/core/compubapi_v1\272\002\014CompubapiV1_'
  _MRZ._serialized_start=51
  _MRZ._serialized_end=197
  _MRZ_TYPE._serialized_start=117
  _MRZ_TYPE._serialized_end=197
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from .filter.required_document import RequiredDocument  # noqa: F401
from yoti_python_sdk.utils import YotiSerializable, remove_null_values


class SessionSpec(YotiSerializable):
    """
    Definition for the Doc Scan Session to be created
    """

    def __init__(
        self,
        client_session_token_ttl,
        resources_ttl,
        user_tracking_id,
        notifications,
        sdk_config,
        requested_checks=None,
        requested_tasks=None,
        required_documents=None,
        block_biometric_consent=None,
        session_deadline=None,
    ):
        """
        :param client_session_token_ttl: the client session token TTL
        :type client_session_token_ttl: int
        :param resources_ttl: the resources TTL
        :type resources_ttl: int
        :param user_tracking_id: the user tracking ID
        :type user_tracking_id: str
        :param notifications: the notification configuration
        :type notifications: NotificationConfig
        :param sdk_config: the SDK configuration
        :type sdk_config: SdkConfig
        :param requested_checks: the list of requested checks
        :type requested_checks: list[RequestedCheck] or None
        :param requested_tasks: the list of requested tasks
        :type requested_tasks: list[RequestedTask] or None
        :param required_documents: the list of required documents
        :type required_documents: list[RequiredDocument] or None
        :param block_biometric_consent: block the collection of biometric consent
        :type block_biometric_consent: bool
        :param session_deadline: session deadline using a Zoned timestamp
        "type session_deadline: str
        """
        if requested_tasks is None:
            requested_tasks = []
        if requested_checks is None:
            requested_checks = []
        if required_documents is None:
            required_documents = []

        self.__client_session_token_ttl = client_session_token_ttl
        self.__resources_ttl = resources_ttl
        self.__user_tracking_id = user_tracking_id
        self.__notifications = notifications
        self.__sdk_config = sdk_config
        self.__requested_checks = requested_checks
        self.__requested_tasks = requested_tasks
        self.__required_documents = required_documents
        self.__block_biometric_consent = block_biometric_consent
        self.__session_deadline = session_deadline

    @property
    def client_session_token_ttl(self):
        """
        Client-session-token time-to-live to apply to the created Session

        :return: the client-session-token time-to-live
        :rtype: int
        """
        return self.__client_session_token_ttl

    @property
    def resources_ttl(self):
        """
        Time-to-live used for all Resources created in the course of the session

        :return: the time-to-live for Resources
        :rtype: int
        """
        return self.__resources_ttl

    @property
    def user_tracking_id(self):
        """
        User tracking ID, to track returning users

        :return: the user tracking ID
        :rtype: str
        """
        return self.__user_tracking_id

    @property
    def notifications(self):
        """
        :class:`NotificationConfig` for configuring call-back messages

        :return: the notification config
        :rtype: NotificationConfig
        """
        return self.__notifications

    @property
    def sdk_config(self):
        """
        Retrieves the SDK configuration set of the session specification

        :return: the SDK config
        :rtype: SdkConfig
        """
        return self.__sdk_config

    @property
    def requested_checks(self):
        """
        List of :class:`RequestedCheck` objects defining the Checks to be performed
        on each Document

        :return: the requested checks
        :rtype: list[RequestedCheck]
        """
        return self.__requested_checks

    @property
    def requested_tasks(self):
        """
        List of :class:`RequestedTask` objects defining the Tasks to be performed
        on each Document

        :return: the requested tasks
        :rtype: list[RequestedTask]
        """
        return self.__requested_tasks

    @property
    def required_documents(self):
        """
        List of documents that are required from the user to satisfy a sessions
        requirements.

        :return: the list of required documents
        :rtype: list[RequiredDocument]
        """
        return self.__required_documents

    @property
    def block_biometric_consent(self):
        """
        Whether or not to block the collection of biometric consent.

        :return: block biometric consent
        :rtype: bool
        """
        return self.__block_biometric_consent

    @property
    def session_deadline(self):
        """
        Session deadline used by IDV

        :return: session deadline
        :rtype: str
        """
        return self.__session_deadline

    def to_json(self):
        return remove_null_values(
            {
                "client_session_token_ttl": self.client_session_token_ttl,
                "resources_ttl": self.resources_ttl,
                "user_tracking_id": self.user_tracking_id,
                "notifications": self.notifications,
                "requested_checks": self.requested_checks,
                "requested_tasks": self.requested_tasks,
                "sdk_config": self.sdk_config,
                "required_documents": self.required_documents,
                "block_biometric_consent": self.block_biometric_consent,
                "session_deadline": self.session_deadline,
            }
        )


class SessionSpecBuilder(object):
    """
    Builder to assist the creation of :class:`SessionSpec`
    """

    def __init__(self):
        self.__client_session_token_ttl = None
        self.__resources_ttl = None
        self.__user_tracking_id = None
        self.__notifications = None
        self.__sdk_config = None
        self.__requested_checks = []
        self.__requested_tasks = []
        self.__required_documents = []
        self.__block_biometric_consent = None
        self.__session_deadline = None

    def with_client_session_token_ttl(self, value):
        """
        Sets the client session token TTL (time-to-live)

        :param value: the client session token TTL
        :type value: int
        :return: the builder
        :rtype: SessionSpecBuilder
        """
        self.__client_session_token_ttl = value
        return self

    def with_session_deadline(self, value):
        """
        Sets the deadline that the session needs to be completed by.
        Can be used as an alternative to with_client_session_token_ttl.

        :param value: the session deadline
        :type value: str
        :return: the builder
        :rtype: SessionSpecBuilder
        """
        self.__session_deadline = value
        return self

    def with_resources_ttl(self, value):
        """
        Sets the resources TTL (time-to-live)

        :param value: the resources TTL
        :type value: int
        :return: the builder
        :rtype: SessionSpecBuilder
        """
        self.__resources_ttl = value
        return self

    def with_user_tracking_id(self, value):
        """
        Sets the user tracking ID

        :param value: the user tracking ID
        :type value: str
        :return: the builder
        :rtype: SessionSpecBuilder
        """
        self.__user_tracking_id = value
        return self

    def with_notifications(self, notifications):
        """
        Sets the notification configuration

        :param notifications: the notification config
        :type notifications: NotificationConfig
        :return: the builder
        :rtype: SessionSpecBuilder
        """
        self.__notifications = notifications
        return self

    def with_requested_check(self, check):
        """
        Adds a :class:`RequestedCheck` to the list

        :param check: the check to add
        :type check: RequestedCheck
        :return: the builder
        :rtype: SessionSpecBuilder
        """
        self.__requested_checks.append(check)
        return self

    def with_requested_task(self, task):
        """
        Adds a :class:`RequestedTask` to the list

        :param task: the task to add
        :type task: RequestedTask
        :return: the builder
        :rtype: SessionSpecBuilder
        """
        self.__requested_tasks.append(task)
        return self

    def with_sdk_config(self, value):
        """
        Sets the SDK configuration

        :param value: the SDK config
        :type value: SdkConfig
        :return: the builder
        :rtype: SessionSpecBuilder
        """
        self.__sdk_config = value
        return self

    def with_required_document(self, required_document):
        """
        Adds a required document to the session specification

        :param required_document: the required document
        :type required_document: RequiredDocument
        :return: the builder
        :rtype: SessionSpecBuilder
        """
        self.__required_documents.append(required_document)
        return self

    def with_block_biometric_consent(self, block_biometric_consent):
        """
        Sets whether or not to block the collection of biometric consent

        :param block_biometric_consent: block biometric consent
        :type block_biometric_consent: bool
        :return: the builder
        :rtype: SessionSpecBuilder
        """
        self.__block_biometric_consent = block_biometric_consent
        return self

    def build(self):
        """
        Builds a :class:`SessionSpec` using the supplied values

        :return: the built Session Specification
        :rtype: SessionSpec
        """
        return SessionSpec(
            self.__client_session_token_ttl,
            self.__resources_ttl,
            self.__user_tracking_id,
            self.__notifications,
            self.__sdk_config,
            self.__requested_checks,
            self.__requested_tasks,
            self.__required_documents,
            self.__block_biometric_consent,
            self.__session_deadline,
        )



# -*- coding: utf-8 -*-
import os
from os import environ
from .version import __version__
from yoti_python_sdk.client import Client

DEFAULTS = {
    "YOTI_API_URL": "https://api.yoti.com",
    "YOTI_API_PORT": 443,
    "YOTI_API_VERSION": "v1",
    "YOTI_API_VERIFY_SSL": "true",
}

main_ns = {}

directory_name = os.path.dirname(__file__)
version_path = os.path.join(directory_name, "version.py")

exec(open(version_path).read())

YOTI_API_URL = environ.get("YOTI_API_URL", DEFAULTS["YOTI_API_URL"])

YOTI_PROFILE_ENDPOINT = "/api/v1"
YOTI_DOC_SCAN_ENDPOINT = "/idverify/v1"

YOTI_API_PORT = environ.get("YOTI_API_PORT", DEFAULTS["YOTI_API_PORT"])
YOTI_API_VERSION = environ.get("YOTI_API_VERSION", DEFAULTS["YOTI_API_VERSION"])

# Fully formatted API URLs
YOTI_API_ENDPOINT = environ.get(
    "YOTI_API_ENDPOINT",
    "{0}:{1}{2}".format(YOTI_API_URL, YOTI_API_PORT, YOTI_PROFILE_ENDPOINT),
)
YOTI_DOC_SCAN_API_URL = environ.get(
    "YOTI_DOC_SCAN_API_URL",
    "{0}:{1}{2}".format(YOTI_API_URL, YOTI_API_PORT, YOTI_DOC_SCAN_ENDPOINT),
)

YOTI_API_VERIFY_SSL = environ.get(
    "YOTI_API_VERIFY_SSL", DEFAULTS["YOTI_API_VERIFY_SSL"]
)
if YOTI_API_VERIFY_SSL.lower() == "false":
    YOTI_API_VERIFY_SSL = False
else:
    YOTI_API_VERIFY_SSL = True

__all__ = ["Client", __version__]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from yoti_python_sdk.doc_scan.constants import CHECK_COMPLETION
from yoti_python_sdk.doc_scan.constants import RESOURCE_UPDATE
from yoti_python_sdk.doc_scan.constants import SESSION_COMPLETION
from yoti_python_sdk.doc_scan.constants import TASK_COMPLETION
from yoti_python_sdk.utils import YotiSerializable, remove_null_values


class NotificationConfig(YotiSerializable):
    """
    Configures call-back Notifications to some backend endpoint provided by the Relying Business.

    Notifications can be configured to notify a clients backend of certain events, avoiding the need
    to poll for the state of the Session.
    """

    def __init__(self, auth_token, endpoint, topics=None, auth_type=None):
        """
        :param auth_token: the authorization token
        :type auth_token: str
        :param endpoint: the endpoint
        :type endpoint: str
        :param topics: the list of topics
        :type topics: list[str]
        """
        if topics is None:
            topics = []

        self.__auth_token = auth_token
        self.__endpoint = endpoint
        self.__topics = list(set(topics))  # Get unique values
        self.__auth_type = auth_type

    @property
    def auth_token(self):
        """
        The authorization token to be included in call-back messages

        :return: the authorization token
        :rtype: str
        """
        return self.__auth_token

    @property
    def endpoint(self):
        """
        The endpoint that notifications should be sent to

        :return: the endpoint
        :rtype: str
        """
        return self.__endpoint

    @property
    def topics(self):
        """
        The list of topics that should trigger notifications

        :return: the list of topics
        :rtype: list[str]
        """
        return self.__topics

    @property
    def auth_type(self):
        """
        The authentication type that the notification will use to
        authenticate itself.

        :return: the endpoint
        :rtype: str
        """
        return self.__auth_type

    def to_json(self):
        return remove_null_values(
            {
                "auth_type": self.auth_type,
                "auth_token": self.auth_token,
                "endpoint": self.endpoint,
                "topics": self.topics,
            }
        )


class NotificationConfigBuilder(object):
    """
    Builder to assist in the creation of :class:`NotificationConfig`
    """

    def __init__(self):
        self.__auth_token = None
        self.__endpoint = None
        self.__topics = []
        self.__auth_type = None

    def with_auth_token(self, token):
        """
        Sets the authorization token to be included in call-back messages

        :param token: the authorization token
        :type token: str
        :return: the builder
        :rtype: NotificationConfigBuilder
        """
        self.__auth_token = token
        return self

    def with_endpoint(self, endpoint):
        """
        Sets the endpoint that notifications should be sent to

        :param endpoint: the endpoint
        :type endpoint: str
        :return: the builder
        :rtype: NotificationConfigBuilder
        """
        self.__endpoint = endpoint
        return self

    def with_topic(self, topic):
        """
        Adds a topic to the list of topics that trigger notification messages

        :param topic: the topic
        :type topic: str
        :return: the builder
        :rtype: NotificationConfigBuilder
        """
        self.__topics.append(topic)
        return self

    def for_resource_update(self):
        """
        Adds RESOURCE_UPDATE to the list of topics that trigger notification messages

        :return: the builder
        :rtype: NotificationConfigBuilder
        """
        return self.with_topic(RESOURCE_UPDATE)

    def for_task_completion(self):
        """
        Adds TASK_COMPLETION to the list of topics that trigger notification messages

        :return: the builder
        :rtype: NotificationConfigBuilder
        """
        return self.with_topic(TASK_COMPLETION)

    def for_session_completion(self):
        """
        Adds SESSION_COMPLETION to the list of topics that trigger notification messages

        :return: the builder
        :rtype: NotificationConfigBuilder
        """
        return self.with_topic(SESSION_COMPLETION)

    def for_check_completion(self):
        """
        Adds CHECK_COMPLETION to the list of topics that trigger notification messages

        :return: the builder
        :rtype: NotificationConfigBuilder
        """
        return self.with_topic(CHECK_COMPLETION)

    def with_basic_auth_type(self):
        """
        Setup "BASIC" auth type for notifications.

        :return: the builder
        :rtype: NotificationConfigBuilder
        """
        self.__auth_type = "BASIC"
        return self

    def with_bearer_auth_type(self):
        """
        Setup "BEARER" auth type for notifications.

        :return: the builder
        :rtype: NotificationConfigBuilder
        """
        self.__auth_type = "BEARER"
        return self

    def build(self):
        """
        Builds the :class:`NotificationConfig` using the supplied values

        :return: the build notification config
        :rtype: NotificationConfig
        """
        return NotificationConfig(self.__auth_token, self.__endpoint, self.__topics, self.__auth_type)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: compubapi_v1/RsaAuthDigest.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import Signature_pb2 as compubapi__v1_dot_Signature__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n compubapi_v1/RsaAuthDigest.proto\x12\x16yoti.core.compubapi_v1\x1a\x1c\x63ompubapi_v1/Signature.proto\"x\n\rRsaAuthDigest\x12\x0f\n\x07pub_key\x18\x01 \x01(\x0c\x12\r\n\x05nonce\x18\x02 \x01(\x0c\x12\x11\n\ttimestamp\x18\x03 \x01(\t\x12\x34\n\tsignature\x18\x04 \x01(\x0b\x32!.yoti.core.compubapi_v1.SignatureBh\n\x15\x63om.yoti.compubapi_v1B\x12RsaAuthDigestProtoZ,go.internal.yoti.com/proto/core/compubapi_v1\xba\x02\x0c\x43ompubapiV1_b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'RsaAuthDigest_pb2.py', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\025com.yoti.compubapi_v1B\022RsaAuthDigestProtoZ,go.internal.yoti.com/proto/core/compubapi_v1\272\002\014CompubapiV1_'
  _RSAAUTHDIGEST._serialized_start=90
  _RSAAUTHDIGEST._serialized_end=210
# @@protoc_insertion_point(module_scope)



class SupportedDocument(object):
    def __init__(self, data=None):
        if data is None:
            data = dict()

        self.__type = data.get("type", None)
        self.__is_strictly_latin = data.get("is_strictly_latin", None)

    @property
    def type(self):
        return self.__type

    @property
    def is_strictly_latin(self):
        return self.__is_strictly_latin


class SupportedCountry(object):
    def __init__(self, data=None):
        if data is None:
            data = dict()

        self.__code = data.get("code", None)
        self.__supported_documents = [
            SupportedDocument(document)
            for document in data.get("supported_documents", [])
        ]

    @property
    def code(self):
        return self.__code

    @property
    def supported_documents(self):
        return self.__supported_documents


class SupportedDocumentsResponse(object):
    def __init__(self, data=None):
        if data is None:
            data = dict()

        self.__supported_countries = [
            SupportedCountry(country) for country in data.get("supported_countries", [])
        ]

    @property
    def supported_countries(self):
        return self.__supported_countries



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from yoti_python_sdk.doc_scan.session.retrieve.id_document_resource_response import (
    IdDocumentResourceResponse,
)
from yoti_python_sdk.doc_scan.session.retrieve.supplementary_document_resource_response import (
    SupplementaryDocumentResourceResponse,
)
from yoti_python_sdk.doc_scan.session.retrieve.liveness_resource_response import (
    LivenessResourceResponse,
    ZoomLivenessResourceResponse,
)


class ResourceContainer(object):
    """
    Contains different resources that are part of the Yoti
    Doc Scan session
    """

    def __init__(self, data=None):
        """
        :param data: the data to parse
        :type data: dict or None
        """
        if data is None:
            data = dict()

        self.__id_documents = [
            IdDocumentResourceResponse(document)
            for document in data.get("id_documents", [])
        ]

        self.__supplementary_documents = [
            SupplementaryDocumentResourceResponse(document)
            for document in data.get("supplementary_documents", [])
        ]

        self.__liveness_capture = [
            self.__parse_liveness_capture(liveness)
            for liveness in data.get("liveness_capture", [])
        ]

    @staticmethod
    def __parse_liveness_capture(liveness_capture):
        """
        Parses a liveness capture into a specific sub-class based on the
        liveness type.  If no liveness type is available, it falls back
        to the parent class :class:`LivenessResourceResponse`

        :param liveness_capture: the liveness capture
        :type liveness_capture: dict
        :return: the parsed liveness capture
        :rtype: LivenessResourceResponse
        """
        types = {"ZOOM": ZoomLivenessResourceResponse}

        clazz = types.get(
            liveness_capture.get("liveness_type", None),
            LivenessResourceResponse,  # Fallback value for unknown type
        )
        return clazz(liveness_capture)

    @property
    def id_documents(self):
        """
        Return a list of ID document resources

        :return: list of ID documents
        :rtype: list[IdDocumentResourceResponse]
        """
        return self.__id_documents

    @property
    def supplementary_documents(self):
        """
        Return a list of supplementary document resources

        :return: list of supplementary documents
        :rtype: list[SupplementaryDocumentResourceResponse]
        """
        return self.__supplementary_documents

    @property
    def liveness_capture(self):
        """
        Return a list of liveness capture resources

        :return: list of liveness captures
        :rtype: list[LivenessResourceResponse]
        """
        return self.__liveness_capture

    @property
    def zoom_liveness_resources(self):
        """
        Returns a filtered list of zoom liveness capture resources

        :return: list of zoom liveness captures
        :rtype: list[ZoomLivenessResourceResponse]
        """
        return [
            liveness
            for liveness in self.__liveness_capture
            if isinstance(liveness, ZoomLivenessResourceResponse)
        ]
